@@ -251,6 +251,8 @@ function configure_manila {
 
     # Set the replica_state_update_interval
     iniset $MANILA_CONF DEFAULT replica_state_update_interval $MANILA_REPLICA_STATE_UPDATE_INTERVAL
+    # Set the use_scheduler_creating_share_from_snapshot
+    iniset $MANILA_CONF DEFAULT use_scheduler_creating_share_from_snapshot $MANILA_USE_SCHEDULER_CREATING_SHARE_FROM_SNAPSHOT
 
     if is_service_enabled neutron; then
         configure_keystone_authtoken_middleware $MANILA_CONF neutron neutron
@@ -832,7 +834,7 @@ function start_manila_api {
 
     if [ $(trueorfalse False MANILA_USE_UWSGI) == True ]; then
         echo "Deploying with UWSGI"
-        run_process m-api "$(which uwsgi) --ini $MANILA_UWSGI_CONF --procname-prefix manila-api"
+        run_process m-api "$MANILA_BIN_DIR/uwsgi --ini $MANILA_UWSGI_CONF --procname-prefix manila-api"
     elif [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
         echo "Deploying with MOD_WSGI"
         install_apache_wsgi
@@ -903,7 +905,7 @@ function stop_manila {
 }
 
 function install_manila_tempest_plugin {
-    MANILA_TEMPEST_PLUGIN_REPO=${MANILA_TEMPEST_PLUGIN_REPO:-${GIT_BASE}/openstack/manila-tempest-plugin.git}
+    MANILA_TEMPEST_PLUGIN_REPO=${MANILA_TEMPEST_PLUGIN_REPO:-${GIT_BASE}/openstack/manila-tempest-plugin}
     MANILA_TEMPEST_PLUGIN_BRANCH=${MANILA_TEMPEST_PLUGIN_BRANCH:-master}
     MANILA_TEMPEST_PLUGIN_DIR=$DEST/manila-tempest-plugin
 
@@ -914,14 +916,6 @@ function install_manila_tempest_plugin {
 # update_tempest - Function used for updating Tempest config if Tempest service enabled
 function update_tempest {
     if is_service_enabled tempest; then
-
-        if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
-            # The public network was created by us, so set it explicitly in
-            # tempest.conf
-            public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
-            iniset $TEMPEST_CONFIG network public_network_id $public_net_id
-        fi
-
         TEMPEST_CONFIG=${TEMPEST_CONFIG:-$TEMPEST_DIR/etc/tempest.conf}
         ADMIN_TENANT_NAME=${ADMIN_TENANT_NAME:-"admin"}
         ADMIN_DOMAIN_NAME=${ADMIN_DOMAIN_NAME:-"Default"}
@@ -1016,33 +1010,6 @@ function install_libraries {
     fi
 }
 
-function allow_host_ports_for_share_mounting {
-
-    if [[ $MANILA_ENABLED_SHARE_PROTOCOLS =~ NFS ]]; then
-        # 111 and 2049 are for rpcbind and NFS
-        # Other ports are for NFSv3 statd, mountd and lockd daemons
-        MANILA_TCP_PORTS=(2049 111 32803 892 875 662)
-        MANILA_UDP_PORTS=(111 32769 892 875 662)
-    fi
-    if [[ $MANILA_ENABLED_SHARE_PROTOCOLS =~ CEPHFS ]]; then
-        # clients need access to the ceph daemons
-        MANILA_TCP_PORTS=(${MANILA_TCP_PORTS[*]} 6789 6800:7300)
-    fi
-
-    if [[ -v MANILA_TCP_PORTS || -v MANILA_UDP_PORTS ]]; then
-        for ipcmd in iptables ip6tables; do
-            sudo $ipcmd -N manila-storage
-            sudo $ipcmd -I INPUT 1 -j manila-storage
-            for port in ${MANILA_TCP_PORTS[*]}; do
-                sudo $ipcmd -A manila-storage -m tcp -p tcp --dport $port -j ACCEPT
-            done
-            for port in ${MANILA_UDP_PORTS[*]}; do
-                sudo $ipcmd -A manila-storage -m udp -p udp --dport $port -j ACCEPT
-            done
-        done
-    fi
-}
-
 function setup_ipv6 {
 
     # This will fail with multiple default routes and is not needed in CI
@@ -1186,14 +1153,6 @@ function setup_ipv6 {
 
 }
 
-function setup_bgp_for_ipv6 {
-    public_gateway_ipv6=$(openstack subnet show ipv6-public-subnet -c gateway_ip -f value)
-    neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
-    neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
-    neutron bgp-peer-create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
-    neutron bgp-speaker-peer-add bgpspeaker bgppeer
-}
-
 # Main dispatcher
 if [[ "$1" == "stack" && "$2" == "install" ]]; then
     echo_summary "Installing Manila Client"
@@ -1271,7 +1230,7 @@ elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
     create_custom_share_types
 
     echo_summary "Manila UI is no longer enabled by default. \
-        Add enable_plugin manila-ui https://git.openstack.org/openstack/manila-ui \
+        Add enable_plugin manila-ui https://opendev.org/openstack/manila-ui \
         to your local.conf file to enable Manila UI"
 
 elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
@@ -1305,19 +1264,6 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
 
     echo_summary "Update Tempest config"
     update_tempest
-
-
-    if [[ "$(trueorfalse False MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST)" == "True" ]]; then
-        echo_summary "Allowing IPv4 and IPv6 access to NAS ports on the host"
-        allow_host_ports_for_share_mounting
-    fi
-
-    if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
-        # Now that all plugins are loaded, setup BGP
-        echo_summary "Setting up BGP speaker to advertise routes to project networks"
-        setup_bgp_for_ipv6
-    fi
-
 fi
 
 if [[ "$1" == "unstack" ]]; then
