@@ -140,13 +140,21 @@ REST_API_VERSION_HISTORY = """
     * 2.51 - Added Share Network with multiple Subnets. Updated Share Networks
              to handle with one or more subnets in different availability
              zones.
+    * 2.52 - Added 'created_before' and 'created_since' field to list messages
+             filters, support querying user messages within the specified time
+             period.
+    * 2.53 - Added quota control to share replicas.
+    * 2.54 - Share and share instance objects include a new field called
+             "progress" which indicates the completion of a share creation
+             operation as a percentage.
+    * 2.55 - Share groups feature is no longer considered experimental.
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # minimum version of the API supported.
 _MIN_API_VERSION = "2.0"
-_MAX_API_VERSION = "2.51"
+_MAX_API_VERSION = "2.55"
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 
