@@ -14,6 +14,7 @@
 #    under the License.
 
 import six
+from six.moves import http_client
 import webob
 
 from manila.api import common
@@ -98,6 +99,7 @@ class ShareTypeExtraSpecsController(wsgi.Controller):
             raise webob.exc.HTTPBadRequest(e.message)
 
         self._check_key_names(specs.keys())
+        specs = share_types.sanitize_extra_specs(specs)
         db.share_type_extra_specs_update_or_create(context, type_id, specs)
         notifier_info = dict(type_id=type_id, specs=specs)
         notifier = rpc.get_notifier('shareTypeExtraSpecs')
@@ -118,11 +120,12 @@ class ShareTypeExtraSpecsController(wsgi.Controller):
             expl = _('Request body contains too many items')
             raise webob.exc.HTTPBadRequest(explanation=expl)
         self._verify_extra_specs(body, False)
-        db.share_type_extra_specs_update_or_create(context, type_id, body)
+        specs = share_types.sanitize_extra_specs(body)
+        db.share_type_extra_specs_update_or_create(context, type_id, specs)
         notifier_info = dict(type_id=type_id, id=id)
         notifier = rpc.get_notifier('shareTypeExtraSpecs')
         notifier.info(context, 'share_type_extra_specs.update', notifier_info)
-        return body
+        return specs
 
     @wsgi.Controller.authorize
     def show(self, req, type_id, id):
@@ -150,7 +153,7 @@ class ShareTypeExtraSpecsController(wsgi.Controller):
 
     @wsgi.Controller.api_version('2.24')  # noqa
     @wsgi.Controller.authorize
-    def delete(self, req, type_id, id):  # pylint: disable=E0102
+    def delete(self, req, type_id, id):  # pylint: disable=function-redefined
         """Deletes an existing extra spec."""
         context = req.environ['manila.context']
         self._check_type(context, type_id)
@@ -173,7 +176,7 @@ class ShareTypeExtraSpecsController(wsgi.Controller):
         notifier_info = dict(type_id=type_id, id=id)
         notifier = rpc.get_notifier('shareTypeExtraSpecs')
         notifier.info(context, 'share_type_extra_specs.delete', notifier_info)
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def _check_key_names(self, keys):
         if not common.validate_key_names(keys):
