@@ -364,8 +364,7 @@ class ShareMixin(object):
                 else:
                     share_type = share_types.get_share_type(
                         context, req_share_type)
-            except (exception.ShareTypeNotFound,
-                    exception.ShareTypeNotFoundByName):
+            except exception.ShareTypeNotFound:
                 msg = _("Share type not found.")
                 raise exc.HTTPNotFound(explanation=msg)
         elif not snapshot:
