@@ -58,12 +58,8 @@ from __future__ import print_function
 import os
 import sys
 
-from manila import i18n
-i18n.enable_lazy()
-
 from oslo_config import cfg
 from oslo_log import log
-from oslo_utils import uuidutils
 
 from manila.common import config  # Need to register global_opts  # noqa
 from manila import context
@@ -75,6 +71,16 @@ from manila import version
 
 CONF = cfg.CONF
 
+HOST_UPDATE_HELP_MSG = ("A fully qualified host string is of the format "
+                        "'HostA@BackendB#PoolC'. Provide only the host name "
+                        "(ex: 'HostA') to update the hostname part of "
+                        "the host string. Provide only the "
+                        "host name and backend name (ex: 'HostA@BackendB') to "
+                        "update the host and backend names.")
+HOST_UPDATE_CURRENT_HOST_HELP = ("Current share host name. %s" %
+                                 HOST_UPDATE_HELP_MSG)
+HOST_UPDATE_NEW_HOST_HELP = "New share host name. %s" % HOST_UPDATE_HELP_MSG
+
 
 # Decorators for actions
 def args(*args, **kwargs):
@@ -84,20 +90,6 @@ def args(*args, **kwargs):
     return _decorator
 
 
-def param2id(object_id):
-    """Helper function to convert various id types to internal id.
-
-    args: [object_id], e.g. 'vol-0000000a' or 'volume-0000000a' or '10'
-    """
-    if uuidutils.is_uuid_like(object_id):
-        return object_id
-    elif '-' in object_id:
-        # FIXME(ja): mapping occurs in nova?
-        pass
-    else:
-        return int(object_id)
-
-
 class ShellCommands(object):
     def bpython(self):
         """Runs a bpython shell.
@@ -355,12 +347,47 @@ class ServiceCommands(object):
             ))
 
 
+class ShareCommands(object):
+
+    @staticmethod
+    def _validate_hosts(current_host, new_host):
+        err = None
+        if '@' in current_host:
+            if '#' in current_host and '#' not in new_host:
+                err = "%(chost)s specifies a pool but %(nhost)s does not."
+            elif '@' not in new_host:
+                err = "%(chost)s specifies a backend but %(nhost)s does not."
+        if err:
+            print(err % {'chost': current_host, 'nhost': new_host})
+            sys.exit(1)
+
+    @args('--currenthost', required=True, help=HOST_UPDATE_CURRENT_HOST_HELP)
+    @args('--newhost', required=True, help=HOST_UPDATE_NEW_HOST_HELP)
+    @args('--force', required=False, type=bool, default=False,
+          help="Ignore validations.")
+    def update_host(self, current_host, new_host, force=False):
+        """Modify the host name associated with a share.
+
+           Particularly to recover from cases where one has moved
+           their Manila Share node, or modified their 'host' opt
+           or their backend section name in the manila configuration file.
+        """
+        if not force:
+            self._validate_hosts(current_host, new_host)
+        ctxt = context.get_admin_context()
+        updated = db.share_instances_host_update(ctxt, current_host, new_host)
+        print("Updated host of %(count)s share instances on %(chost)s "
+              "to %(nhost)s." % {'count': updated, 'chost': current_host,
+                                 'nhost': new_host})
+
+
 CATEGORIES = {
     'config': ConfigCommands,
     'db': DbCommands,
     'host': HostCommands,
     'logs': GetLogCommands,
     'service': ServiceCommands,
+    'share': ShareCommands,
     'shell': ShellCommands,
     'version': VersionCommands
 }
@@ -447,17 +474,9 @@ def main():
         CONF(sys.argv[1:], project='manila',
              version=version.version_string())
         log.setup(CONF, "manila")
-    except cfg.ConfigFilesNotFoundError:
-        cfgfile = CONF.config_file[-1] if CONF.config_file else None
-        if cfgfile and not os.access(cfgfile, os.R_OK):
-            st = os.stat(cfgfile)
-            print(_("Could not read %s. Re-running with sudo") % cfgfile)
-            try:
-                os.execvp('sudo', ['sudo', '-u', '#%s' % st.st_uid] + sys.argv)
-            except Exception:
-                print(_('sudo failed, continuing as if nothing happened'))
-
-        print(_('Please re-run manila-manage as root.'))
+    except cfg.ConfigFilesNotFoundError as e:
+        cfg_files = e.config_files
+        print(_("Failed to read configuration file(s): %s") % cfg_files)
         sys.exit(2)
 
     fn = CONF.category.action_fn
