@@ -77,22 +77,6 @@ global_opts = [
     cfg.ListOpt('osapi_share_extension',
                 default=['manila.api.contrib.standard_extensions'],
                 help='The osapi share extensions to load.'),
-    cfg.StrOpt('sqlite_db',
-               default='manila.sqlite',
-               help='The filename to use with sqlite.'),
-    cfg.BoolOpt('sqlite_synchronous',
-                default=True,
-                help='If passed, use synchronous mode for sqlite.'),
-    cfg.IntOpt('sql_idle_timeout',
-               default=3600,
-               help='Timeout before idle SQL connections are reaped.'),
-    cfg.IntOpt('sql_max_retries',
-               default=10,
-               help='Maximum database connection retries during startup. '
-                    '(setting -1 implies an infinite retry count).'),
-    cfg.IntOpt('sql_retry_interval',
-               default=10,
-               help='Interval between retries of opening a SQL connection.'),
     cfg.StrOpt('scheduler_manager',
                default='manila.scheduler.manager.SchedulerManager',
                help='Full class name for the scheduler manager.'),
@@ -117,15 +101,16 @@ global_opts = [
     cfg.StrOpt('default_share_group_type',
                help='Default share group type to use.'),
     cfg.ListOpt('memcached_servers',
-                help='Memcached servers or None for in process cache.'),
+                help='Memcached servers or None for in process cache.',
+                deprecated_reason="The config option is not used. It should "
+                "not be confused with [keystone_authtoken]/memcached_servers.",
+                deprecated_for_removal=True),
     cfg.StrOpt('share_usage_audit_period',
                default='month',
+               deprecated_for_removal=True,
                help='Time period to generate share usages for.  '
-                    'Time period must be hour, day, month or year.'),
-    cfg.StrOpt('root_helper',
-               default='sudo',
-               help='Deprecated: command to use for running commands as '
-                    'root.'),
+                    'Time period must be hour, day, month or year.',
+               deprecated_reason="The config option is not used."),
     cfg.StrOpt('rootwrap_config',
                help='Path to the rootwrap configuration file to use for '
                     'running commands as root.'),
