@@ -340,10 +340,11 @@ def share_instances_get_all_by_share_server(context, share_server_id):
                                                         share_server_id)
 
 
-def share_instances_get_all_by_host(context, host, with_share_data=False):
+def share_instances_get_all_by_host(context, host, with_share_data=False,
+                                    status=None):
     """Returns all share instances with given host."""
     return IMPL.share_instances_get_all_by_host(
-        context, host, with_share_data=with_share_data)
+        context, host, with_share_data=with_share_data, status=status)
 
 
 def share_instances_get_all_by_share_network(context, share_network_id):
@@ -1305,9 +1306,11 @@ def share_replica_update(context, share_replica_id, values,
                                      with_share_data=with_share_data)
 
 
-def share_replica_delete(context, share_replica_id):
+def share_replica_delete(context, share_replica_id,
+                         need_to_update_usages=True):
     """Deletes a share replica."""
-    return IMPL.share_replica_delete(context, share_replica_id)
+    return IMPL.share_replica_delete(
+        context, share_replica_id, need_to_update_usages=need_to_update_usages)
 
 
 def purge_deleted_records(context, age_in_days):
@@ -1411,9 +1414,11 @@ def message_get(context, message_id):
     return IMPL.message_get(context, message_id)
 
 
-def message_get_all(context, filters=None, sort_key=None, sort_dir=None):
+def message_get_all(context, filters=None, limit=None, offset=None,
+                    sort_key=None, sort_dir=None):
     """Returns all messages with the project of the specified context."""
-    return IMPL.message_get_all(context, filters=filters, sort_key=sort_key,
+    return IMPL.message_get_all(context, filters=filters, limit=limit,
+                                offset=offset, sort_key=sort_key,
                                 sort_dir=sort_dir)
 
 
