@@ -257,6 +257,11 @@ class Share(BASE, ManilaBase):
             return len(replicas) > 1
         return False
 
+    @property
+    def progress(self):
+        if len(self.instances) > 0:
+            return self.instance.progress
+
     @property
     def instance(self):
         # NOTE(gouthamr): The order of preference: status 'replication_change',
@@ -364,6 +369,7 @@ class ShareInstance(BASE, ManilaBase):
     deleted = Column(String(36), default='False')
     host = Column(String(255))
     status = Column(String(255))
+    progress = Column(String(32))
 
     ACCESS_STATUS_PRIORITIES = {
         constants.STATUS_ACTIVE: 0,
@@ -938,7 +944,9 @@ class ShareNetwork(BASE, ManilaBase):
                     'ShareNetwork.id == ShareInstance.share_network_id,'
                     'ShareInstance.deleted == "False")')
     share_network_subnets = orm.relationship(
-        "ShareNetworkSubnet", backref='share_network', lazy='immediate',
+        "ShareNetworkSubnet",
+        lazy='joined',
+        backref=orm.backref('share_network', lazy='joined'),
         primaryjoin='and_'
                     '(ShareNetwork.id == ShareNetworkSubnet.share_network_id,'
                     'ShareNetworkSubnet.deleted == "False")')
@@ -990,6 +998,10 @@ class ShareNetworkSubnet(BASE, ManilaBase):
     def is_default(self):
         return self.availability_zone_id is None
 
+    @property
+    def share_network_name(self):
+        return self.share_network['name']
+
 
 class ShareServer(BASE, ManilaBase):
     """Represents share server used by share."""
@@ -1216,7 +1228,7 @@ class ShareGroupSnapshot(BASE, ManilaBase):
     status = Column(String(255))
     share_group = orm.relationship(
         ShareGroup,
-        backref="snapshots",
+        backref=orm.backref("snapshots", lazy='joined'),
         foreign_keys=share_group_id,
         primaryjoin=('and_('
                      'ShareGroupSnapshot.share_group_id == ShareGroup.id,'
