@@ -103,7 +103,7 @@ class ManilaException(Exception):
         elif isinstance(message, Exception):
             message = six.text_type(message)
 
-        if re.match('.*[^\.]\.\.$', message):
+        if re.match(r'.*[^\.]\.\.$', message):
             message = message[:-1]
         self.msg = message
         super(ManilaException, self).__init__(message)
@@ -443,6 +443,17 @@ class ShareGroupSnapshotsLimitExceeded(QuotaError):
         "Maximum number of allowed share-group-snapshots is exceeded.")
 
 
+class ShareReplicasLimitExceeded(QuotaError):
+    message = _(
+        "Maximum number of allowed share-replicas is exceeded.")
+
+
+class ShareReplicaSizeExceedsAvailableQuota(QuotaError):
+    message = _(
+        "Requested share replica exceeds allowed project/user or share type "
+        "gigabytes quota.")
+
+
 class GlusterfsException(ManilaException):
     message = _("Unknown Gluster exception.")
 
