@@ -91,6 +91,7 @@ class Manager(base.Base, PeriodicTasks):
             host = CONF.host
         self.host = host
         self.additional_endpoints = []
+        self.availability_zone = CONF.storage_availability_zone
         super(Manager, self).__init__(db_driver)
 
     def periodic_tasks(self, context, raise_on_error=False):
@@ -114,6 +115,15 @@ class Manager(base.Base, PeriodicTasks):
             config[key] = CONF.get(key, None)
         return config
 
+    def is_service_ready(self):
+        """Method indicating if service is ready.
+
+        This method should be overridden by subclasses which will return False
+        when the back end is not ready yet.
+
+        """
+        return True
+
 
 class SchedulerDependentManager(Manager):
     """Periodically send capability updates to the Scheduler services.
