@@ -349,8 +349,8 @@ class IpRouteCommand(IpDeviceCommandBase):
                 subnet = device_route_line.split()[0]
             except Exception:
                 continue
-            subnet_route_list_lines = self._run('list', 'proto', 'kernel',
-                                                'match', subnet).split('\n')
+            subnet_route_list_lines = self._run(
+                'list', 'proto', 'kernel', 'exact', subnet).split('\n')
             for subnet_route_line in subnet_route_list_lines:
                 i = iter(subnet_route_line.split())
                 while(next(i) != 'dev'):
@@ -415,7 +415,7 @@ class IpRouteCommand(IpDeviceCommandBase):
         return routes
 
     def delete_net_route(self, cidr, device):
-        """Deletes a route according to suplied CIDR and interface device.
+        """Deletes a route according to supplied CIDR and interface device.
 
         :param cidr: The network CIDR to be removed.
         :param device: The network interface device to be removed.
