@@ -31,6 +31,7 @@ import manila.common.config
 import manila.compute
 import manila.compute.nova
 import manila.coordination
+import manila.data.helper
 import manila.db.api
 import manila.db.base
 import manila.exception
@@ -57,7 +58,7 @@ import manila.share.drivers.container.driver
 import manila.share.drivers.container.storage_helper
 import manila.share.drivers.dell_emc.driver
 import manila.share.drivers.dell_emc.plugins.isilon.isilon
-import manila.share.drivers.dell_emc.plugins.vmax.connection
+import manila.share.drivers.dell_emc.plugins.powermax.connection
 import manila.share.drivers.generic
 import manila.share.drivers.glusterfs
 import manila.share.drivers.glusterfs.common
@@ -71,6 +72,9 @@ import manila.share.drivers.hpe.hpe_3par_driver
 import manila.share.drivers.huawei.huawei_nas
 import manila.share.drivers.ibm.gpfs
 import manila.share.drivers.infinidat.infinibox
+import manila.share.drivers.infortrend.driver
+import manila.share.drivers.inspur.as13000.as13000_nas
+import manila.share.drivers.inspur.instorage.instorage
 import manila.share.drivers.lvm
 import manila.share.drivers.maprfs.maprfs_native
 import manila.share.drivers.netapp.options
@@ -102,6 +106,7 @@ _global_opt_lists = [
     manila.common.config.global_opts,
     manila.compute._compute_opts,
     manila.coordination.coordination_opts,
+    manila.data.helper.data_helper_opts,
     manila.db.api.db_opts,
     [manila.db.base.db_driver_opt],
     manila.exception.exc_log_opts,
@@ -138,7 +143,7 @@ _global_opt_lists = [
     manila.share.drivers.container.driver.container_opts,
     manila.share.drivers.container.storage_helper.lv_opts,
     manila.share.drivers.dell_emc.driver.EMC_NAS_OPTS,
-    manila.share.drivers.dell_emc.plugins.vmax.connection.VMAX_OPTS,
+    manila.share.drivers.dell_emc.plugins.powermax.connection.POWERMAX_OPTS,
     manila.share.drivers.generic.share_opts,
     manila.share.drivers.glusterfs.common.glusterfs_common_opts,
     manila.share.drivers.glusterfs.GlusterfsManilaShare_opts,
@@ -155,6 +160,9 @@ _global_opt_lists = [
     manila.share.drivers.infinidat.infinibox.infinidat_auth_opts,
     manila.share.drivers.infinidat.infinibox.infinidat_connection_opts,
     manila.share.drivers.infinidat.infinibox.infinidat_general_opts,
+    manila.share.drivers.infortrend.driver.infortrend_nas_opts,
+    manila.share.drivers.inspur.as13000.as13000_nas.inspur_as13000_opts,
+    manila.share.drivers.inspur.instorage.instorage.instorage_opts,
     manila.share.drivers.maprfs.maprfs_native.maprfs_native_share_opts,
     manila.share.drivers.lvm.share_opts,
     manila.share.drivers.netapp.options.netapp_proxy_opts,
