@@ -45,6 +45,12 @@ quota_opts = [
     cfg.IntOpt('quota_share_networks',
                default=10,
                help='Number of share-networks allowed per project.'),
+    cfg.IntOpt('quota_share_replicas',
+               default=100,
+               help='Number of share-replicas allowed per project.'),
+    cfg.IntOpt('quota_replica_gigabytes',
+               default=1000,
+               help='Number of replica gigabytes allowed per project.'),
 
     cfg.IntOpt('quota_share_groups',
                default=50,
@@ -346,9 +352,9 @@ class DbQuotaDriver(object):
 
         # Filter resources
         if has_sync:
-            sync_filt = lambda x: hasattr(x, 'sync')
+            sync_filt = lambda x: hasattr(x, 'sync')  # noqa: E731
         else:
-            sync_filt = lambda x: not hasattr(x, 'sync')
+            sync_filt = lambda x: not hasattr(x, 'sync')  # noqa: E731
         desired = set(keys)
         sub_resources = {k: v for k, v in resources.items()
                          if k in desired and sync_filt(v)}
@@ -581,8 +587,8 @@ class DbQuotaDriver(object):
         :param share_type_id: The UUID of the share type.
         """
 
-        db.quota_destroy_all_by_project_and_share_type(
-            context, project_id, share_type_id)
+        db.quota_destroy_all_by_share_type(context, share_type_id,
+                                           project_id=project_id)
 
     def expire(self, context):
         """Expire reservations.
@@ -1059,6 +1065,10 @@ resources = [
                        'quota_share_groups'),
     ReservableResource('share_group_snapshots', '_sync_share_group_snapshots',
                        'quota_share_group_snapshots'),
+    ReservableResource('share_replicas', '_sync_share_replicas',
+                       'quota_share_replicas'),
+    ReservableResource('replica_gigabytes', '_sync_replica_gigabytes',
+                       'quota_replica_gigabytes'),
 ]
 
 
