@@ -46,7 +46,11 @@ share_api_opts = [
                 default=False,
                 help='If set to False, then share creation from snapshot will '
                      'be performed on the same host. '
-                     'If set to True, then scheduling step will be used.')
+                     'If set to True, then scheduler will be used.'
+                     'When enabling this option make sure that filter '
+                     'CreateShareFromSnapshot is enabled and to have hosts '
+                     'reporting replication_domain option.'
+                )
 ]
 
 CONF = cfg.CONF
@@ -76,6 +80,78 @@ class API(base.Base):
                 compatible_azs.append(az['name'])
         return compatible_azs
 
+    def _check_if_share_quotas_exceeded(self, context, quota_exception,
+                                        share_size, operation='create'):
+        overs = quota_exception.kwargs['overs']
+        usages = quota_exception.kwargs['usages']
+        quotas = quota_exception.kwargs['quotas']
+
+        def _consumed(name):
+            return (usages[name]['reserved'] + usages[name]['in_use'])
+
+        if 'gigabytes' in overs:
+            LOG.warning("Quota exceeded for %(s_pid)s, "
+                        "tried to %(operation)s "
+                        "%(s_size)sG share (%(d_consumed)dG of "
+                        "%(d_quota)dG already consumed).", {
+                            's_pid': context.project_id,
+                            's_size': share_size,
+                            'd_consumed': _consumed('gigabytes'),
+                            'd_quota': quotas['gigabytes'],
+                            'operation': operation})
+            raise exception.ShareSizeExceedsAvailableQuota()
+        elif 'shares' in overs:
+            LOG.warning("Quota exceeded for %(s_pid)s, "
+                        "tried to %(operation)s "
+                        "share (%(d_consumed)d shares "
+                        "already consumed).", {
+                            's_pid': context.project_id,
+                            'd_consumed': _consumed('shares'),
+                            'operation': operation})
+            raise exception.ShareLimitExceeded(allowed=quotas['shares'])
+
+    def _check_if_replica_quotas_exceeded(self, context, quota_exception,
+                                          replica_size,
+                                          resource_type='share_replica'):
+        overs = quota_exception.kwargs['overs']
+        usages = quota_exception.kwargs['usages']
+        quotas = quota_exception.kwargs['quotas']
+
+        def _consumed(name):
+            return (usages[name]['reserved'] + usages[name]['in_use'])
+
+        if 'share_replicas' in overs:
+            LOG.warning("Quota exceeded for %(s_pid)s, "
+                        "unable to create share-replica (%(d_consumed)d "
+                        "of %(d_quota)d already consumed).", {
+                            's_pid': context.project_id,
+                            'd_consumed': _consumed('share_replicas'),
+                            'd_quota': quotas['share_replicas']})
+            exception_kwargs = {}
+            if resource_type != 'share_replica':
+                msg = _("Failed while creating a share with replication "
+                        "support. Maximum number of allowed share-replicas "
+                        "is exceeded.")
+                exception_kwargs['message'] = msg
+            raise exception.ShareReplicasLimitExceeded(**exception_kwargs)
+        elif 'replica_gigabytes' in overs:
+            LOG.warning("Quota exceeded for %(s_pid)s, "
+                        "unable to create a share replica size of "
+                        "%(s_size)sG (%(d_consumed)dG of "
+                        "%(d_quota)dG already consumed).", {
+                            's_pid': context.project_id,
+                            's_size': replica_size,
+                            'd_consumed': _consumed('replica_gigabytes'),
+                            'd_quota': quotas['replica_gigabytes']})
+            exception_kwargs = {}
+            if resource_type != 'share_replica':
+                msg = _("Failed while creating a share with replication "
+                        "support. Requested share replica exceeds allowed "
+                        "project/user or share type gigabytes quota.")
+                exception_kwargs['message'] = msg
+            raise exception.ShareReplicaSizeExceedsAvailableQuota(
+                **exception_kwargs)
+
     def create(self, context, share_proto, size, name, description,
                snapshot_id=None, availability_zone=None, metadata=None,
                share_network_id=None, share_type=None, is_public=False,
@@ -118,7 +194,18 @@ class API(base.Base):
             share_type_id = share_type['id'] if share_type else None
         else:
             source_share = self.db.share_get(context, snapshot['share_id'])
-            availability_zone = source_share['instance']['availability_zone']
+            source_share_az = source_share['instance']['availability_zone']
+            if availability_zone is None:
+                availability_zone = source_share_az
+            elif (availability_zone != source_share_az
+                  and not CONF.use_scheduler_creating_share_from_snapshot):
+                LOG.error("The specified availability zone must be the same "
+                          "as parent share when you have the configuration "
+                          "option 'use_scheduler_creating_share_from_snapshot'"
+                          " set to False.")
+                msg = _("The specified availability zone must be the same "
+                        "as the parent share when creating from snapshot.")
+                raise exception.InvalidInput(reason=msg)
             if share_type is None:
                 # Grab the source share's share_type if no new share type
                 # has been provided.
@@ -146,37 +233,23 @@ class API(base.Base):
                          supported=CONF.enabled_share_protocols))
             raise exception.InvalidInput(reason=msg)
 
+        deltas = {'shares': 1, 'gigabytes': size}
+        share_type_attributes = self.get_share_attributes_from_share_type(
+            share_type)
+        share_type_supports_replication = share_type_attributes.get(
+            'replication_type', None)
+        if share_type_supports_replication:
+            deltas.update(
+                {'share_replicas': 1, 'replica_gigabytes': size})
+
         try:
             reservations = QUOTAS.reserve(
-                context, shares=1, gigabytes=size,
-                share_type_id=share_type_id,
-            )
+                context, share_type_id=share_type_id, **deltas)
         except exception.OverQuota as e:
-            overs = e.kwargs['overs']
-            usages = e.kwargs['usages']
-            quotas = e.kwargs['quotas']
-
-            def _consumed(name):
-                return (usages[name]['reserved'] + usages[name]['in_use'])
-
-            if 'gigabytes' in overs:
-                LOG.warning("Quota exceeded for %(s_pid)s, "
-                            "tried to create "
-                            "%(s_size)sG share (%(d_consumed)dG of "
-                            "%(d_quota)dG already consumed).", {
-                                's_pid': context.project_id,
-                                's_size': size,
-                                'd_consumed': _consumed('gigabytes'),
-                                'd_quota': quotas['gigabytes']})
-                raise exception.ShareSizeExceedsAvailableQuota()
-            elif 'shares' in overs:
-                LOG.warning("Quota exceeded for %(s_pid)s, "
-                            "tried to create "
-                            "share (%(d_consumed)d shares "
-                            "already consumed).", {
-                                's_pid': context.project_id,
-                                'd_consumed': _consumed('shares')})
-                raise exception.ShareLimitExceeded(allowed=quotas['shares'])
+            self._check_if_share_quotas_exceeded(context, e, size)
+            if share_type_supports_replication:
+                self._check_if_replica_quotas_exceeded(context, e, size,
+                                                       resource_type='share')
 
         share_group = None
         if share_group_id:
@@ -231,7 +304,7 @@ class API(base.Base):
             'is_public': is_public,
             'share_group_id': share_group_id,
         }
-        options.update(self.get_share_attributes_from_share_type(share_type))
+        options.update(share_type_attributes)
 
         if share_group_snapshot_member:
             options['source_share_group_snapshot_member_id'] = (
@@ -269,19 +342,23 @@ class API(base.Base):
                         context, reservations, share_type_id=share_type_id)
 
         host = None
-        if snapshot and not CONF.use_scheduler_creating_share_from_snapshot:
-            # Shares from snapshots with restriction - source host only.
-            # It is common situation for different types of backends.
-            host = snapshot['share']['instance']['host']
+        snapshot_host = None
+        if snapshot:
+            snapshot_host = snapshot['share']['instance']['host']
+            if not CONF.use_scheduler_creating_share_from_snapshot:
+                # Shares from snapshots with restriction - source host only.
+                # It is common situation for different types of backends.
+                host = snapshot['share']['instance']['host']
 
-        elif share_group:
+        if share_group and host is None:
             host = share_group['host']
 
         self.create_instance(
             context, share, share_network_id=share_network_id, host=host,
             availability_zone=availability_zone, share_group=share_group,
             share_group_snapshot_member=share_group_snapshot_member,
-            share_type_id=share_type_id, availability_zones=availability_zones)
+            share_type_id=share_type_id, availability_zones=availability_zones,
+            snapshot_host=snapshot_host)
 
         # Retrieve the share with instance details
         share = self.db.share_get(context, share['id'])
@@ -357,14 +434,16 @@ class API(base.Base):
     def create_instance(self, context, share, share_network_id=None,
                         host=None, availability_zone=None,
                         share_group=None, share_group_snapshot_member=None,
-                        share_type_id=None, availability_zones=None):
+                        share_type_id=None, availability_zones=None,
+                        snapshot_host=None):
         request_spec, share_instance = (
             self.create_share_instance_and_get_request_spec(
                 context, share, availability_zone=availability_zone,
                 share_group=share_group, host=host,
                 share_network_id=share_network_id,
                 share_type_id=share_type_id,
-                availability_zones=availability_zones))
+                availability_zones=availability_zones,
+                snapshot_host=snapshot_host))
 
         if share_group_snapshot_member:
             # Inherit properties from the share_group_snapshot_member
@@ -403,7 +482,7 @@ class API(base.Base):
             self, context, share, availability_zone=None,
             share_group=None, host=None, share_network_id=None,
             share_type_id=None, cast_rules_to_readonly=False,
-            availability_zones=None):
+            availability_zones=None, snapshot_host=None):
 
         availability_zone_id = None
         if availability_zone:
@@ -470,6 +549,7 @@ class API(base.Base):
             'share_proto': share['share_proto'],
             'share_id': share['id'],
             'snapshot_id': share['snapshot_id'],
+            'snapshot_host': snapshot_host,
             'share_type': share_type,
             'share_group': share_group,
             'availability_zone_id': availability_zone_id,
@@ -513,6 +593,14 @@ class API(base.Base):
                        'az': availability_zone}
             raise exception.InvalidShare(message=msg % payload)
 
+        try:
+            reservations = QUOTAS.reserve(
+                context, share_replicas=1, replica_gigabytes=share['size'],
+                share_type_id=share_type['id']
+            )
+        except exception.OverQuota as e:
+            self._check_if_replica_quotas_exceeded(context, e, share['size'])
+
         if share_network_id:
             if availability_zone:
                 try:
@@ -552,14 +640,29 @@ class API(base.Base):
             cast_rules_to_readonly = True
         else:
             cast_rules_to_readonly = False
-        request_spec, share_replica = (
-            self.create_share_instance_and_get_request_spec(
-                context, share, availability_zone=availability_zone,
-                share_network_id=share_network_id,
-                share_type_id=share['instance']['share_type_id'],
-                cast_rules_to_readonly=cast_rules_to_readonly,
-                availability_zones=type_azs)
-        )
+
+        try:
+            request_spec, share_replica = (
+                self.create_share_instance_and_get_request_spec(
+                    context, share, availability_zone=availability_zone,
+                    share_network_id=share_network_id,
+                    share_type_id=share['instance']['share_type_id'],
+                    cast_rules_to_readonly=cast_rules_to_readonly,
+                    availability_zones=type_azs)
+            )
+            QUOTAS.commit(
+                context, reservations, project_id=share['project_id'],
+                share_type_id=share_type['id'],
+            )
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                try:
+                    self.db.share_replica_delete(
+                        context, share_replica['id'],
+                        need_to_update_usages=False)
+                finally:
+                    QUOTAS.rollback(
+                        context, reservations, share_type_id=share_type['id'])
 
         all_replicas = self.db.share_replicas_get_all_by_share(
             context, share['id'])
@@ -666,28 +769,18 @@ class API(base.Base):
         self.share_rpcapi.update_share_replica(context, share_replica)
 
     def manage(self, context, share_data, driver_options):
-
-        # Check whether there's a share already with the provided options:
-        filters = {
-            'export_location_path': share_data['export_location_path'],
+        shares = self.get_all(context, {
             'host': share_data['host'],
-        }
-        share_server_id = share_data.get('share_server_id')
-        if share_server_id:
-            filters['share_server_id'] = share_data['share_server_id']
-
-        already_managed = self.db.share_instances_get_all(context,
-                                                          filters=filters)
-
-        if already_managed:
-            LOG.error("Found an existing share with export location %s!",
-                      share_data['export_location_path'])
-            msg = _("A share already exists with the export path specified.")
-            raise exception.InvalidShare(reason=msg)
+            'export_location': share_data['export_location'],
+            'share_proto': share_data['share_proto'],
+            'share_type_id': share_data['share_type_id']
+        })
 
         share_type_id = share_data['share_type_id']
         share_type = share_types.get_share_type(context, share_type_id)
 
+        share_server_id = share_data.get('share_server_id')
+
         dhss = share_types.parse_boolean_extra_spec(
             'driver_handles_share_servers',
             share_type['extra_specs']['driver_handles_share_servers'])
@@ -727,11 +820,18 @@ class API(base.Base):
         share_data.update(
             self.get_share_attributes_from_share_type(share_type))
 
-        share = self.db.share_create(context, share_data)
+        LOG.debug("Manage: Found shares %s.", len(shares))
+
+        export_location = share_data.pop('export_location')
+
+        if len(shares) == 0:
+            share = self.db.share_create(context, share_data)
+        else:
+            msg = _("Share already exists.")
+            raise exception.InvalidShare(reason=msg)
 
-        export_location_path = share_data.pop('export_location_path')
         self.db.share_export_locations_update(context, share.instance['id'],
-                                              export_location_path)
+                                              export_location)
 
         request_spec = self._get_request_spec_dict(
             share, share_type, size=0, share_proto=share_data['share_proto'],
@@ -1565,8 +1665,8 @@ class API(base.Base):
                 context, service_host, 'manila-share')
 
             if utils.service_is_up(service):
-                    self.share_rpcapi.migration_cancel(
-                        context, share_instance_ref, migrating_instance_id)
+                self.share_rpcapi.migration_cancel(
+                    context, share_instance_ref, migrating_instance_id)
             else:
                 migrating = False
 
@@ -1843,7 +1943,7 @@ class API(base.Base):
             raise exception.InvalidShare(message=msg)
 
         for share_instance in share.instances:
-                self.deny_access_to_instance(ctx, share_instance, access)
+            self.deny_access_to_instance(ctx, share_instance, access)
 
     def deny_access_to_instance(self, context, share_instance, access):
         self._conditionally_transition_share_instance_access_rules_status(
@@ -1967,34 +2067,64 @@ class API(base.Base):
                                                     'size': share['size']})
             raise exception.InvalidInput(reason=msg)
 
+        replicas = self.db.share_replicas_get_all_by_share(
+            context, share['id'])
+        supports_replication = len(replicas) > 0
+
+        deltas = {
+            'project_id': share['project_id'],
+            'gigabytes': size_increase,
+            'user_id': share['user_id'],
+            'share_type_id': share['instance']['share_type_id']
+        }
+
+        # NOTE(carloss): If the share type supports replication, we must get
+        # all the replicas that pertain to the share and calculate the final
+        # size (size to increase * amount of replicas), since all the replicas
+        # are going to be extended when the driver sync them.
+        if supports_replication:
+            replica_gigs_to_increase = len(replicas) * size_increase
+            deltas.update({'replica_gigabytes': replica_gigs_to_increase})
+
         try:
             # we give the user_id of the share, to update the quota usage
             # for the user, who created the share, because on share delete
             # only this quota will be decreased
-            reservations = QUOTAS.reserve(
-                context,
-                project_id=share['project_id'],
-                gigabytes=size_increase,
-                user_id=share['user_id'],
-                share_type_id=share['instance']['share_type_id'])
+            reservations = QUOTAS.reserve(context, **deltas)
         except exception.OverQuota as exc:
-            usages = exc.kwargs['usages']
-            quotas = exc.kwargs['quotas']
+            # Check if the exceeded quota was 'gigabytes'
+            self._check_if_share_quotas_exceeded(context, exc, share['size'],
+                                                 operation='extend')
+            # NOTE(carloss): Check if the exceeded quota is
+            # 'replica_gigabytes'. If so the failure could be caused due to
+            # lack of quotas to extend the share's replicas, then the
+            # '_check_if_replica_quotas_exceeded' method can't be reused here
+            # since the error message must be different from the default one.
+            if supports_replication:
+                overs = exc.kwargs['overs']
+                usages = exc.kwargs['usages']
+                quotas = exc.kwargs['quotas']
 
-            def _consumed(name):
-                return usages[name]['reserved'] + usages[name]['in_use']
+                def _consumed(name):
+                    return (usages[name]['reserved'] + usages[name]['in_use'])
 
-            msg = ("Quota exceeded for %(s_pid)s, tried to extend share "
-                   "by %(s_size)sG, (%(d_consumed)dG of %(d_quota)dG "
-                   "already consumed).")
-            LOG.error(msg, {'s_pid': context.project_id,
-                            's_size': size_increase,
-                            'd_consumed': _consumed('gigabytes'),
-                            'd_quota': quotas['gigabytes']})
-            raise exception.ShareSizeExceedsAvailableQuota(
-                requested=size_increase,
-                consumed=_consumed('gigabytes'),
-                quota=quotas['gigabytes'])
+                if 'replica_gigabytes' in overs:
+                    LOG.warning("Replica gigabytes quota exceeded "
+                                "for %(s_pid)s, tried to extend "
+                                "%(s_size)sG share (%(d_consumed)dG of "
+                                "%(d_quota)dG already consumed).", {
+                                    's_pid': context.project_id,
+                                    's_size': share['size'],
+                                    'd_consumed': _consumed(
+                                        'replica_gigabytes'),
+                                    'd_quota': quotas['replica_gigabytes']})
+                    msg = _("Failed while extending a share with replication "
+                            "support. There is no available quota to extend "
+                            "the share and its %(count)d replicas. Maximum "
+                            "number of allowed replica_gigabytes is "
+                            "exceeded.") % {'count': len(replicas)}
+                    raise exception.ShareReplicaSizeExceedsAvailableQuota(
+                        message=msg)
 
         self.update(context, share, {'status': constants.STATUS_EXTENDING})
         self.share_rpcapi.extend_share(context, share, new_size, reservations)
