@@ -38,8 +38,11 @@ from manila import utils
     1.0.0 - Initial version
     2.0.0 - Implement IPv6 support
     3.0.0 - Rebranding to PowerMax
+    3.1.0 - Access Host details prevents a read-only share mounts
+            (bug #1845147)
+    3.2.0 - Wrong format of export locations (bug #1871999)
 """
-VERSION = "3.0.0"
+VERSION = "3.2.0"
 
 LOG = log.getLogger(__name__)
 
@@ -125,7 +128,9 @@ class PowerMaxStorageConnection(driver.StorageConnection):
         elif share_proto == 'CIFS':
             location = self._create_cifs_share(share_name, share_server)
 
-        return location
+        return [
+            {'path': location}
+        ]
 
     def _share_server_validation(self, share_server):
         """Validate the share server."""
@@ -189,13 +194,9 @@ class PowerMaxStorageConnection(driver.StorageConnection):
 
         self._get_context('CIFSShare').disable_share_access(share_name,
                                                             vdm_name)
-        locations = []
         location = (r'\\%(interface)s\%(name)s' %
                     {'interface': interface, 'name': share_name})
-
-        locations.append(location)
-
-        return locations
+        return location
 
     @enas_utils.log_enter_exit
     def _create_nfs_share(self, share_name, share_server):
@@ -212,7 +213,7 @@ class PowerMaxStorageConnection(driver.StorageConnection):
                    'share_name': share_name})
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Create a share from a snapshot - clone a snapshot."""
         share_name = share['id']
 
@@ -247,7 +248,9 @@ class PowerMaxStorageConnection(driver.StorageConnection):
         elif share_proto == 'CIFS':
             location = self._create_cifs_share(share_name, share_server)
 
-        return location
+        return [
+            {'path': location}
+        ]
 
     def create_snapshot(self, context, snapshot, share_server=None):
         """Create snapshot from share."""
@@ -631,9 +634,8 @@ class PowerMaxStorageConnection(driver.StorageConnection):
 
                 pool_stat = {
                     'pool_name': pool['name'],
-                    'total_capacity_gb': enas_utils.mb_to_gb(total_size),
-                    'free_capacity_gb':
-                        enas_utils.mb_to_gb(total_size - used_size),
+                    'total_capacity_gb': total_size,
+                    'free_capacity_gb': total_size - used_size,
                     'qos': False,
                     'reserved_percentage': self.reserved_percentage,
                     'snapshot_support': True,
