@@ -39,8 +39,10 @@ from manila import utils
     3.0.0 - Bumped the version for Ocata
     4.0.0 - Bumped the version for Pike
     5.0.0 - Bumped the version for Queens
+    9.0.0 - Bumped the version for Ussuri
+    9.0.1 - Fixes bug 1871999: wrong format of export locations
 """
-VERSION = "5.0.0"
+VERSION = "9.0.1"
 
 LOG = log.getLogger(__name__)
 
@@ -125,7 +127,9 @@ class VNXStorageConnection(driver.StorageConnection):
         elif share_proto == 'CIFS':
             location = self._create_cifs_share(share_name, share_server)
 
-        return location
+        return [
+            {'path': location}
+        ]
 
     def _share_server_validation(self, share_server):
         """Validate the share server."""
@@ -210,7 +214,7 @@ class VNXStorageConnection(driver.StorageConnection):
                    'share_name': share_name})
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Create a share from a snapshot - clone a snapshot."""
         share_name = share['id']
 
@@ -245,7 +249,9 @@ class VNXStorageConnection(driver.StorageConnection):
         elif share_proto == 'CIFS':
             location = self._create_cifs_share(share_name, share_server)
 
-        return location
+        return [
+            {'path': location}
+        ]
 
     def create_snapshot(self, context, snapshot, share_server=None):
         """Create snapshot from share."""
