@@ -165,7 +165,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
 
         # (aovchinnikov): ssh_execute does not behave well when passed
         # parameters with spaces.
-        wrap = lambda token: "\"" + token + "\""
+        wrap = lambda token: "\"" + token + "\""  # noqa: E731
         command = [wrap(tkn) if tkn.count(' ') else tkn for tkn in command]
         return processutils.ssh_execute(ssh, ' '.join(command),
                                         check_exit_code=check_exit_code)
@@ -304,7 +304,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         try:
             # Remount it to avoid postponed point of failure
             self._ssh_exec(server_details, ['sudo', 'mount', '-a'])
-        except exception.ProcessExecutionError as e:
+        except exception.ProcessExecutionError:
             LOG.error("Failed to mount all shares on server '%s'.",
                       server_details['instance_id'])
 
@@ -498,7 +498,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             volume_snapshot = volume_snapshot_list[0]
         elif len(volume_snapshot_list) > 1:
             LOG.error(
-                "Expected only one volume snapshot in list with name"
+                "Expected only one volume snapshot in list with name "
                 "'%(name)s', but got more than one in a result - "
                 "'%(result)s'.", {
                     'name': volume_snapshot_name,
@@ -640,7 +640,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
 
     @ensure_server
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Is called to create share from snapshot."""
         return self._create_share(
             context, share,
