@@ -151,12 +151,12 @@ netapp_data_motion_opts = [
                help='The maximum time in seconds to wait for the completion '
                     'of a volume move operation after the cutover '
                     'was triggered.'),
-    cfg.IntOpt('netapp_migration_cancel_timeout',
+    cfg.IntOpt('netapp_start_volume_move_timeout',
                min=0,
                default=3600,  # One Hour,
-               help='The maximum time in seconds that migration cancel '
-                    'waits for all migration operations be completely '
-                    'aborted.'), ]
+               help='The maximum time in seconds to wait for the completion '
+                    'of a volume clone split operation in order to start a '
+                    'volume move.'), ]
 
 CONF = cfg.CONF
 CONF.register_opts(netapp_proxy_opts)
