@@ -189,7 +189,7 @@ class NexentaNasDriver(driver.ShareDriver):
         return '%s:%s' % (self.nas_host, filesystem['mountPoint'])
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Is called to create share from snapshot."""
         snapshot_path = self._get_snapshot_path(snapshot)
         LOG.debug('Creating share from snapshot %s.', snapshot_path)
