@@ -23,13 +23,12 @@ inline callbacks.
 
 import os
 import shutil
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
-import oslo_i18n
 import oslo_messaging
 from oslo_messaging import conffixture as messaging_conffixture
 from oslo_utils import uuidutils
@@ -49,6 +48,9 @@ test_opts = [
     cfg.StrOpt('sqlite_clean_db',
                default='clean.sqlite',
                help='File name of clean sqlite database.'),
+    cfg.StrOpt('sqlite_db',
+               default='manila.sqlite',
+               help='The filename to use with sqlite.'),
 ]
 
 CONF = cfg.CONF
@@ -87,7 +89,7 @@ class Database(fixtures.Fixture):
         if self.sql_connection == "sqlite://":
             conn = self.engine.connect()
             conn.connection.executescript(self._DB)
-            self.addCleanup(self.engine.dispose)  # pylint: disable=E1101
+            self.addCleanup(self.engine.dispose)  # pylint: disable=no-member
         else:
             shutil.copyfile(
                 os.path.join(CONF.state_path, self.sqlite_clean_db),
@@ -108,7 +110,6 @@ class TestCase(base_test.BaseTestCase):
         """Run before each test method to initialize test environment."""
         super(TestCase, self).setUp()
 
-        oslo_i18n.enable_lazy(enable=False)
         conf_fixture.set_defaults(CONF)
         CONF([], default_config_files=[])
 
@@ -138,7 +139,7 @@ class TestCase(base_test.BaseTestCase):
         self.addCleanup(rpc.cleanup)
 
         self.messaging_conf = messaging_conffixture.ConfFixture(CONF)
-        self.messaging_conf.transport_driver = 'fake'
+        self.messaging_conf.transport_url = 'fake:/'
         self.messaging_conf.response_timeout = 15
         self.useFixture(self.messaging_conf)
 
@@ -360,9 +361,11 @@ class TestCase(base_test.BaseTestCase):
                 if k not in ignored_keys}
 
     def _assertEqualListsOfObjects(self, objs1, objs2, ignored_keys=None):
-        obj_to_dict = lambda o: self._dict_from_object(o, ignored_keys)
-        sort_key = lambda d: [d[k] for k in sorted(d)]
-        conv_and_sort = lambda obj: sorted(map(obj_to_dict, obj), key=sort_key)
+        obj_to_dict = lambda o: (  # noqa: E731
+            self._dict_from_object(o, ignored_keys))
+        sort_key = lambda d: [d[k] for k in sorted(d)]  # noqa: E731
+        conv_and_sort = lambda obj: (  # noqa: E731
+            sorted(map(obj_to_dict, obj), key=sort_key))
 
         self.assertEqual(conv_and_sort(objs1), conv_and_sort(objs2))
 
