@@ -13,10 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 import webob
 
+from manila.api import common
 from manila.api.v1 import share_manage
 from manila.db import api as db_api
 from manila import exception
@@ -52,6 +54,9 @@ class ShareManageTest(test.TestCase):
         self.context = self.request.environ['manila.context']
         self.mock_policy_check = self.mock_object(
             policy, 'check_policy', mock.Mock(return_value=True))
+        self.mock_object(
+            common, 'validate_public_share_policy',
+            mock.Mock(side_effect=lambda *args, **kwargs: args[1]))
 
     @ddt.data({},
               {'shares': {}},
@@ -114,9 +119,9 @@ class ShareManageTest(test.TestCase):
 
     def test_share_manage_duplicate_share(self):
         body = get_fake_manage_body()
+        exc = exception.InvalidShare(reason="fake")
         self._setup_manage_mocks()
-        self.mock_object(share_api.API, 'manage',
-                         mock.Mock(side_effect=exception.ManilaException()))
+        self.mock_object(share_api.API, 'manage', mock.Mock(side_effect=exc))
 
         self.assertRaises(webob.exc.HTTPConflict,
                           self.controller.create,
@@ -151,6 +156,36 @@ class ShareManageTest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'manage')
 
+    def test_share_manage_invalid_input(self):
+        body = get_fake_manage_body()
+        self._setup_manage_mocks()
+        error = mock.Mock(side_effect=exception.InvalidInput(message="",
+                                                             reason="fake"))
+        self.mock_object(share_api.API, 'manage', mock.Mock(side_effect=error))
+
+        self.assertRaises(webob.exc.HTTPBadRequest,
+                          self.controller.create,
+                          self.request,
+                          body)
+        self.mock_policy_check.assert_called_once_with(
+            self.context, self.resource_name, 'manage')
+
+    def test_share_manage_invalid_share_server(self):
+        body = get_fake_manage_body()
+        self._setup_manage_mocks()
+        error = mock.Mock(
+            side_effect=exception.InvalidShareServer(message="",
+                                                     share_server_id="")
+        )
+        self.mock_object(share_api.API, 'manage', mock.Mock(side_effect=error))
+
+        self.assertRaises(webob.exc.HTTPConflict,
+                          self.controller.create,
+                          self.request,
+                          body)
+        self.mock_policy_check.assert_called_once_with(
+            self.context, self.resource_name, 'manage')
+
     @ddt.data(
         get_fake_manage_body(name='foo', description='bar'),
         get_fake_manage_body(display_name='foo', description='bar'),
@@ -183,6 +218,32 @@ class ShareManageTest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'manage')
 
+    def test_share_manage_allow_dhss_true(self):
+        self._setup_manage_mocks()
+        data = get_fake_manage_body(name='foo', description='bar')
+        return_share = {'share_type_id': '', 'id': 'fake'}
+        self.mock_object(
+            share_api.API, 'manage', mock.Mock(return_value=return_share))
+        share = {
+            'host': data['share']['service_host'],
+            'export_location': data['share']['export_path'],
+            'share_proto': data['share']['protocol'].upper(),
+            'share_type_id': 'fake',
+            'display_name': 'foo',
+            'display_description': 'bar',
+            'share_server_id': 'fake'
+        }
+        data['share']['share_server_id'] = 'fake'
+        driver_options = data['share'].get('driver_options', {})
+
+        self.controller._manage(self.request, data, allow_dhss_true=True)
+
+        share_api.API.manage.assert_called_once_with(
+            self.context, share, driver_options
+        )
+        self.mock_policy_check.assert_called_once_with(
+            self.context, self.resource_name, 'manage')
+
     def test_wrong_permissions(self):
         body = get_fake_manage_body()
         fake_req = fakes.HTTPRequest.blank(
