@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 import six
@@ -580,15 +581,9 @@ class ShareReplicasApiTest(test.TestCase):
         # validate response code and model status
         self.assertEqual(valid_code, resp.status_int)
 
-        if valid_code == 404:
-            self.assertRaises(exception.ShareReplicaNotFound,
-                              share_replicas.db.share_replica_get,
-                              context,
-                              replica['id'])
-        else:
-            actual_replica = share_replicas.db.share_replica_get(
-                context, replica['id'])
-            self.assertEqual(valid_status, actual_replica[status_attr])
+        actual_replica = share_replicas.db.share_replica_get(
+            context, replica['id'])
+        self.assertEqual(valid_status, actual_replica[status_attr])
 
     @ddt.data(*fakes.fixture_reset_replica_status_with_different_roles)
     @ddt.unpack
@@ -663,7 +658,7 @@ class ShareReplicasApiTest(test.TestCase):
     def test_force_delete_missing_replica(self):
         replica, req = self._create_replica_get_req()
         share_replicas.db.share_replica_delete(
-            self.admin_context, replica['id'])
+            self.admin_context, replica['id'], need_to_update_usages=False)
 
         self._force_delete(self.admin_context, req, valid_code=404)
 
@@ -671,10 +666,9 @@ class ShareReplicasApiTest(test.TestCase):
 
         replica, req = self._create_replica_get_req()
         share_replicas.db.share_replica_delete(
-            self.admin_context, replica['id'])
+            self.admin_context, replica['id'], need_to_update_usages=False)
         share_api_call = self.mock_object(self.controller.share_api,
                                           'update_share_replica')
-
         body = {'resync': {}}
         req.body = six.b(jsonutils.dumps(body))
         req.environ['manila.context'] = self.admin_context
