@@ -12,8 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 import six
@@ -232,17 +233,10 @@ class ShareSnapshotInstancesApiTest(test.TestCase):
         # validate response code and model status
         self.assertEqual(valid_code, resp.status_int)
 
-        if valid_code == 404:
-            self.assertRaises(exception.ShareSnapshotInstanceNotFound,
-                              (share_snapshot_instances.db.
-                               share_snapshot_instance_get),
-                              context,
-                              instance['id'])
-        else:
-            actual_instance = (
-                share_snapshot_instances.db.share_snapshot_instance_get(
-                    context, instance['id']))
-            self.assertEqual(valid_status, actual_instance['status'])
+        actual_instance = (
+            share_snapshot_instances.db.share_snapshot_instance_get(
+                context, instance['id']))
+        self.assertEqual(valid_status, actual_instance['status'])
 
     @ddt.data(*fakes.fixture_reset_status_with_different_roles)
     @ddt.unpack
