@@ -14,9 +14,11 @@
 # under the License.
 
 import datetime
+import random
+from unittest import mock
 
 import ddt
-import mock
+from oslo_config import cfg
 from oslo_utils import timeutils
 import webob
 
@@ -32,6 +34,8 @@ from manila import test
 from manila.tests.api import fakes
 from manila.tests import fake_notifier
 
+CONF = cfg.CONF
+
 
 def stub_share_type(id):
     specs = {
@@ -42,15 +46,25 @@ def stub_share_type(id):
         "key5": "value5",
         constants.ExtraSpecs.DRIVER_HANDLES_SHARE_SERVERS: "true",
     }
-    return dict(
-        id=id,
-        name='share_type_%s' % str(id),
-        description='description_%s' % str(id),
-        extra_specs=specs,
-        required_extra_specs={
+    if id == 4:
+        name = 'update_share_type_%s' % str(id)
+        description = 'update_description_%s' % str(id)
+        is_public = False
+    else:
+        name = 'share_type_%s' % str(id)
+        description = 'description_%s' % str(id)
+        is_public = True
+    share_type = {
+        'id': id,
+        'name': name,
+        'description': description,
+        'is_public': is_public,
+        'extra_specs': specs,
+        'required_extra_specs': {
             constants.ExtraSpecs.DRIVER_HANDLES_SHARE_SERVERS: "true",
         }
-    )
+    }
+    return share_type
 
 
 def return_share_types_get_all_types(context, search_opts=None):
@@ -61,6 +75,34 @@ def return_share_types_get_all_types(context, search_opts=None):
     )
 
 
+def stub_default_name():
+    return 'default_share_type'
+
+
+def stub_default_share_type(id):
+    return dict(
+        id=id,
+        name=stub_default_name(),
+        description='description_%s' % str(id),
+        required_extra_specs={
+            constants.ExtraSpecs.DRIVER_HANDLES_SHARE_SERVERS: "true",
+        }
+    )
+
+
+def return_all_share_types(context, search_opts=None):
+    mock_value = dict(
+        share_type_1=stub_share_type(1),
+        share_type_2=stub_share_type(2),
+        share_type_3=stub_default_share_type(3)
+    )
+    return mock_value
+
+
+def return_default_share_type(context, search_opts=None):
+    return stub_default_share_type(3)
+
+
 def return_empty_share_types_get_all_types(context, search_opts=None):
     return {}
 
@@ -71,6 +113,20 @@ def return_share_types_get_share_type(context, id=1):
     return stub_share_type(int(id))
 
 
+def return_share_type_update(context, id=4, name=None, description=None,
+                             is_public=None):
+    if id == 888:
+        raise exception.ShareTypeUpdateFailed(id=id)
+    if id == 999:
+        raise exception.ShareTypeNotFound(share_type_id=id)
+    pre_share_type = stub_share_type(int(id))
+    new_name = name
+    new_description = description
+    return pre_share_type.update({"name": new_name,
+                                  "description": new_description,
+                                  "is_public": is_public})
+
+
 def return_share_types_get_by_name(context, name):
     if name == "777":
         raise exception.ShareTypeNotFoundByName(share_type_name=name)
@@ -115,11 +171,33 @@ def make_create_body(name="test_share_1", extra_specs=None,
     return body
 
 
+def generate_long_description(des_length=256):
+    random_str = ''
+    base_str = 'ABCDEFGHIGKLMNOPQRSTUVWXYZabcdefghigklmnopqrstuvwxyz'
+    length = len(base_str) - 1
+    for i in range(des_length):
+        random_str += base_str[random.randint(0, length)]
+    return random_str
+
+
+def make_update_body(name=None, description=None, is_public=None):
+    body = {"share_type": {}}
+    if name:
+        body["share_type"].update({"name": name})
+    if description:
+        body["share_type"].update({"description": description})
+    if is_public is not None:
+        body["share_type"].update(
+            {"share_type_access:is_public": is_public})
+
+    return body
+
+
 @ddt.ddt
 class ShareTypesAPITest(test.TestCase):
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareTypesAPITest, self).setUp()
         self.flags(host='fake')
         self.controller = types.ShareTypesController()
         self.resource_name = self.controller.resource_name
@@ -136,6 +214,9 @@ class ShareTypesAPITest(test.TestCase):
         self.mock_object(
             share_types, 'get_share_type',
             mock.Mock(side_effect=return_share_types_get_share_type))
+        self.mock_object(
+            share_types, 'update',
+            mock.Mock(side_effect=return_share_type_update))
         self.mock_object(
             share_types, 'destroy',
             mock.Mock(side_effect=return_share_types_destroy))
@@ -359,6 +440,92 @@ class ShareTypesAPITest(test.TestCase):
                           self.controller._parse_is_public,
                           'fakefakefake')
 
+    @ddt.data(
+        ("new_name", "new_description", "wrong_bool"),
+        (" ", "new_description", "true"),
+        (" ", generate_long_description(256), "true"),
+        (None, None, None),
+    )
+    @ddt.unpack
+    def test_share_types_update_with_invalid_parameter(
+            self, name, description, is_public):
+        req = fakes.HTTPRequest.blank('/v2/fake/types/4',
+                                      version='2.50')
+        body = make_update_body(name, description, is_public)
+        self.assertRaises(webob.exc.HTTPBadRequest,
+                          self.controller.update,
+                          req, 4, body)
+        self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
+
+    def test_share_types_update_with_invalid_body(self):
+        req = fakes.HTTPRequest.blank('/v2/fake/types/4',
+                                      version='2.50')
+        body = {'share_type': 'i_am_invalid_body'}
+        self.assertRaises(webob.exc.HTTPBadRequest,
+                          self.controller.update,
+                          req, 4, body)
+        self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
+
+    def test_share_types_update(self):
+        req = fakes.HTTPRequest.blank('/v2/fake/types/4',
+                                      version='2.50')
+        self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
+        body = make_update_body("update_share_type_4",
+                                "update_description_4",
+                                is_public=False)
+        res_dict = self.controller.update(req, 4, body)
+        self.assertEqual(1, len(fake_notifier.NOTIFICATIONS))
+        self.assertEqual(2, len(res_dict))
+
+        self.assertEqual('update_share_type_4', res_dict['share_type']['name'])
+        self.assertEqual('update_share_type_4',
+                         res_dict['volume_type']['name'])
+        self.assertIs(False,
+                      res_dict['share_type']['share_type_access:is_public'])
+
+        self.assertEqual('update_description_4',
+                         res_dict['share_type']['description'])
+        self.assertEqual('update_description_4',
+                         res_dict['volume_type']['description'])
+
+    def test_share_types_update_pre_v250(self):
+        req = fakes.HTTPRequest.blank('/v2/fake/types/4',
+                                      version='2.49')
+        self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
+        body = make_update_body("update_share_type_4",
+                                "update_description_4",
+                                is_public=False)
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+                          self.controller.update,
+                          req, 4, body)
+        self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
+
+    def test_share_types_update_failed(self):
+        self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
+        req = fakes.HTTPRequest.blank('/v2/fake/types/888',
+                                      version='2.50')
+        body = make_update_body("update_share_type_888",
+                                "update_description_888",
+                                is_public=False)
+        self.assertRaises(webob.exc.HTTPInternalServerError,
+                          self.controller.update,
+                          req, 888, body)
+        self.assertEqual(1, len(fake_notifier.NOTIFICATIONS))
+
+    def test_share_types_update_not_found(self):
+        self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
+        req = fakes.HTTPRequest.blank('/v2/fake/types/999',
+                                      version='2.50')
+
+        body = make_update_body("update_share_type_999",
+                                "update_description_999",
+                                is_public=False)
+
+        self.assertRaises(exception.ShareTypeNotFound,
+                          self.controller.update,
+                          req, 999, body)
+        self.assertEqual(1, len(fake_notifier.NOTIFICATIONS))
+
     def test_share_types_delete(self):
         req = fakes.HTTPRequest.blank('/v2/fake/types/1')
         self.assertEqual(0, len(fake_notifier.NOTIFICATIONS))
@@ -491,6 +658,65 @@ class ShareTypesAPITest(test.TestCase):
         for d1, d2 in zip(expected, observed):
             self.assertEqual(d1['id'], d2['id'])
 
+    @ddt.data(('2.45', True), ('2.45', False),
+              ('2.46', True), ('2.46', False))
+    @ddt.unpack
+    def test_share_types_create_with_is_default_key(self, version, admin):
+        req = fakes.HTTPRequest.blank('/v2/fake/types',
+                                      version=version,
+                                      use_admin_context=admin)
+
+        body = make_create_body()
+        res_dict = self.controller.create(req, body)
+        if self.is_microversion_ge(version, '2.46'):
+            self.assertIn('is_default', res_dict['share_type'])
+            self.assertIs(False, res_dict['share_type']['is_default'])
+        else:
+            self.assertNotIn('is_default', res_dict['share_type'])
+
+    @ddt.data(('2.45', True), ('2.45', False),
+              ('2.46', True), ('2.46', False))
+    @ddt.unpack
+    def test_share_types_index_with_is_default_key(self, version, admin):
+        default_type_name = stub_default_name()
+        CONF.set_default("default_share_type", default_type_name)
+        self.mock_object(share_types, 'get_all_types',
+                         return_all_share_types)
+
+        req = fakes.HTTPRequest.blank('/v2/fake/types',
+                                      version=version,
+                                      use_admin_context=admin)
+
+        res_dict = self.controller.index(req)
+        self.assertEqual(3, len(res_dict['share_types']))
+        for res in res_dict['share_types']:
+            if self.is_microversion_ge(version, '2.46'):
+                self.assertIn('is_default', res)
+                expected = res['name'] == default_type_name
+                self.assertIs(res['is_default'], expected)
+            else:
+                self.assertNotIn('is_default', res)
+
+    @ddt.data(('2.45', True), ('2.45', False),
+              ('2.46', True), ('2.46', False))
+    @ddt.unpack
+    def test_share_types_default_with_is_default_key(self, version, admin):
+        default_type_name = stub_default_name()
+        CONF.set_default("default_share_type", default_type_name)
+        self.mock_object(share_types, 'get_default_share_type',
+                         return_default_share_type)
+
+        req = fakes.HTTPRequest.blank('/v2/fake/types/default_share_type',
+                                      version=version,
+                                      use_admin_context=admin)
+
+        res_dict = self.controller.default(req)
+        if self.is_microversion_ge(version, '2.46'):
+            self.assertIn('is_default', res_dict['share_type'])
+            self.assertIs(True, res_dict['share_type']['is_default'])
+        else:
+            self.assertNotIn('is_default', res_dict['share_type'])
+
 
 def generate_type(type_id, is_public):
     return {
@@ -569,7 +795,7 @@ class FakeRequest(object):
 class ShareTypeAccessTest(test.TestCase):
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareTypeAccessTest, self).setUp()
         self.controller = types.ShareTypesController()
         self.req = FakeRequest()
         self.mock_object(db, 'share_type_get', fake_share_type_get)
