@@ -15,10 +15,8 @@
 
 
 from oslo_config import cfg
-from oslo_log import log
 
 CONF = cfg.CONF
-LOG = log.getLogger(__name__)
 
 
 class FakeServer(object):
@@ -45,6 +43,7 @@ class FakeServer(object):
 class FakeKeypair(object):
     def __init__(self, **kwargs):
         self.id = kwargs.pop('id', 'fake_keypair_id')
+        self.name = None
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -75,9 +74,6 @@ class API(object):
     def instance_volumes_list(self, ctx, server_id):
         pass
 
-    def server_list(self, ctx, search_opts, all_tenants):
-        pass
-
     def server_create(self, *args, **kwargs):
         pass
 
@@ -105,6 +101,9 @@ class API(object):
     def image_list(self, *args, **kwargs):
         pass
 
+    def image_get(self, *args, **kwargs):
+        pass
+
     def security_group_create(self, *args, **kwargs):
         pass
 
