@@ -14,14 +14,13 @@
 #    under the License.
 
 import copy
+from unittest import mock
 
 import ddt
-import mock
 from oslo_log import log
 
 from manila import exception
 from manila.share.drivers.dell_emc.common.enas import connector
-from manila.share.drivers.dell_emc.common.enas import utils as enas_utils
 from manila.share.drivers.dell_emc.plugins.vnx import connection
 from manila.share.drivers.dell_emc.plugins.vnx import object_manager
 from manila import test
@@ -174,9 +173,10 @@ class StorageConnectionTestCase(test.TestCase):
         ssh_calls = [mock.call(self.cifs_share.cmd_disable_access(), True)]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, r'\\%s\%s' %
-                         (fakes.FakeData.network_allocations_ip1,
-                          share['name']),
+        self.assertEqual(location,
+                         [{'path': r'\\%s\%s' % (
+                             fakes.FakeData.network_allocations_ip1,
+                             share['name'])}],
                          'CIFS export path is incorrect')
 
     def test_create_cifs_share_with_ipv6(self):
@@ -215,11 +215,12 @@ class StorageConnectionTestCase(test.TestCase):
         ssh_calls = [mock.call(self.cifs_share.cmd_disable_access(), True)]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, r'\\%s.ipv6-literal.net\%s' %
-                         (fakes.FakeData.network_allocations_ip3.replace(
-                             ':', '-'),
-                          share['name']),
-                         'CIFS export path is incorrect')
+        self.assertEqual(
+            location,
+            [{'path': r'\\%s.ipv6-literal.net\%s' % (
+                fakes.FakeData.network_allocations_ip3.replace(':', '-'),
+                share['name'])}],
+            'CIFS export path is incorrect')
 
     def test_create_nfs_share(self):
         share_server = fakes.SHARE_SERVER
@@ -249,7 +250,8 @@ class StorageConnectionTestCase(test.TestCase):
         ssh_calls = [mock.call(self.nfs_share.cmd_create(), True)]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, '192.168.1.2:/%s' % share['name'],
+        self.assertEqual(location,
+                         [{'path': '192.168.1.2:/%s' % share['name']}],
                          'NFS export path is incorrect')
 
     def test_create_nfs_share_with_ipv6(self):
@@ -282,9 +284,10 @@ class StorageConnectionTestCase(test.TestCase):
         ssh_calls = [mock.call(self.nfs_share.cmd_create(), True)]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, '[%s]:/%s' %
-                         (fakes.FakeData.network_allocations_ip4,
-                          share['name']),
+        self.assertEqual(location,
+                         [{'path': '[%s]:/%s' % (
+                             fakes.FakeData.network_allocations_ip4,
+                             share['name'])}],
                          'NFS export path is incorrect')
 
     def test_create_cifs_share_without_share_server(self):
@@ -413,7 +416,8 @@ class StorageConnectionTestCase(test.TestCase):
         ]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, r'\\192.168.1.1\%s' % share['name'],
+        self.assertEqual(location,
+                         [{'path': r'\\192.168.1.1\%s' % share['name']}],
                          'CIFS export path is incorrect')
 
     def test_create_cifs_share_from_snapshot_with_ipv6(self):
@@ -474,11 +478,12 @@ class StorageConnectionTestCase(test.TestCase):
         ]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, r'\\%s.ipv6-literal.net\%s' %
-                         (fakes.FakeData.network_allocations_ip3.replace(':',
-                                                                         '-'),
-                          share['name']),
-                         'CIFS export path is incorrect')
+        self.assertEqual(
+            location,
+            [{'path': r'\\%s.ipv6-literal.net\%s' % (
+                fakes.FakeData.network_allocations_ip3.replace(':', '-'),
+                share['name'])}],
+            'CIFS export path is incorrect')
 
     def test_create_nfs_share_from_snapshot(self):
         share_server = fakes.SHARE_SERVER
@@ -526,7 +531,8 @@ class StorageConnectionTestCase(test.TestCase):
         ]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, '192.168.1.2:/%s' % share['name'],
+        self.assertEqual(location,
+                         [{'path': '192.168.1.2:/%s' % share['name']}],
                          'NFS export path is incorrect')
 
     def test_create_nfs_share_from_snapshot_with_ipv6(self):
@@ -575,10 +581,12 @@ class StorageConnectionTestCase(test.TestCase):
         ]
         ssh_cmd_mock.assert_has_calls(ssh_calls)
 
-        self.assertEqual(location, '[%s]:/%s' %
-                         (fakes.FakeData.network_allocations_ip4,
-                          share['name']),
-                         'NFS export path is incorrect')
+        self.assertEqual(
+            location,
+            [{'path': '[%s]:/%s' % (
+                fakes.FakeData.network_allocations_ip4,
+                share['name'])}],
+            'NFS export path is incorrect')
 
     def test_create_share_with_incorrect_proto(self):
         share_server = fakes.SHARE_SERVER
@@ -2213,14 +2221,12 @@ class StorageConnectionTestCase(test.TestCase):
 
         for pool in fakes.STATS['pools']:
             if pool['pool_name'] == fakes.FakeData.pool_name:
-                self.assertEqual(
-                    enas_utils.mb_to_gb(fakes.FakeData.pool_total_size),
-                    pool['total_capacity_gb'])
+                self.assertEqual(fakes.FakeData.pool_total_size,
+                                 pool['total_capacity_gb'])
 
                 free_size = (fakes.FakeData.pool_total_size -
                              fakes.FakeData.pool_used_size)
-                self.assertEqual(enas_utils.mb_to_gb(free_size),
-                                 pool['free_capacity_gb'])
+                self.assertEqual(free_size, pool['free_capacity_gb'])
 
     def test_update_share_stats_without_matched_config_pools(self):
         self.connection.pools = set('fake_pool')
