@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from stevedore import extension
 
 from manila.share import configuration as conf
@@ -24,6 +25,7 @@ from manila import test
 
 class FakeConnection(base.StorageConnection):
     def __init__(self, *args, **kwargs):
+        self.ipv6_implemented = True
         pass
 
     @property
@@ -42,6 +44,9 @@ class FakeConnection(base.StorageConnection):
     def extend_share(self, share, new_size, share_server):
         """Is called to extend share."""
 
+    def shrink_share(self, share, new_size, share_server):
+        """Is called to shrink share."""
+
     def delete_snapshot(self, context, snapshot, share_server):
         """Is called to remove snapshot."""
 
@@ -74,6 +79,7 @@ class FakeConnection(base.StorageConnection):
     def teardown_server(self, server_details, security_services=None):
         """Teardown share server."""
 
+
 FAKE_BACKEND = 'fake_backend'
 
 
@@ -141,3 +147,59 @@ class EMCShareFrameworkTestCase(test.TestCase):
         elif value == 'driver_handles_share_servers':
             return True
         return None
+
+    def test_support_manage(self):
+        share = mock.Mock()
+        driver_options = mock.Mock()
+        share_server = mock.Mock()
+        snapshot = mock.Mock()
+        context = mock.Mock()
+        identifier = mock.Mock()
+        self.driver.plugin = mock.Mock()
+        self.driver.manage_existing_support = True
+        self.driver.manage_existing_with_server_support = True
+        self.driver.manage_existing_snapshot_support = True
+        self.driver.manage_snapshot_with_server_support = True
+        self.driver.manage_server_support = True
+        self.driver.manage_existing(share, driver_options)
+        self.driver.manage_existing_with_server(share, driver_options,
+                                                share_server)
+        self.driver.manage_existing_snapshot(snapshot, driver_options)
+        self.driver.manage_existing_snapshot_with_server(snapshot,
+                                                         driver_options,
+                                                         share_server)
+        self.driver.manage_server(context, share_server, identifier,
+                                  driver_options)
+
+    def test_not_support_manage(self):
+        share = mock.Mock()
+        driver_options = {}
+        share_server = mock.Mock()
+        snapshot = mock.Mock()
+        identifier = mock.Mock()
+        self.driver.plugin = mock.Mock()
+        result = self.driver.manage_existing(share, driver_options)
+        self.assertIsInstance(result, NotImplementedError)
+        result = self.driver.manage_existing_with_server(
+            share, driver_options, share_server)
+        self.assertIsInstance(result, NotImplementedError)
+        result = self.driver.manage_existing_snapshot(snapshot, driver_options)
+        self.assertIsInstance(result, NotImplementedError)
+        result = self.driver.manage_existing_snapshot_with_server(
+            snapshot, driver_options, share_server)
+        self.assertIsInstance(result, NotImplementedError)
+        result = self.driver.manage_server(None, share_server, identifier,
+                                           driver_options)
+        self.assertIsInstance(result, NotImplementedError)
+
+    def test_unmanage_manage(self):
+        share = mock.Mock()
+        server_details = {}
+        share_server = mock.Mock()
+        snapshot = mock.Mock()
+        self.driver.plugin = mock.Mock(share)
+        self.driver.unmanage(share)
+        self.driver.unmanage_with_server(share, share_server)
+        self.driver.unmanage_snapshot(snapshot)
+        self.driver.unmanage_snapshot_with_server(snapshot, share_server)
+        self.driver.unmanage_server(server_details)
