@@ -18,8 +18,9 @@
 Test cases for GlusterFS native protocol driver.
 """
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 
 from manila.common import constants
@@ -82,7 +83,7 @@ class GlusterfsNativeShareDriverTestCase(test.TestCase):
             'root@host2:/manila-share-2-2G'])
 
         CONF.set_default('glusterfs_volume_pattern',
-                         'manila-share-\d+-#{size}G$')
+                         r'manila-share-\d+-#{size}G$')
         CONF.set_default('driver_handles_share_servers', False)
 
         self.fake_conf = config.Configuration(None)
@@ -256,9 +257,17 @@ class GlusterfsNativeShareDriverTestCase(test.TestCase):
             'free_capacity_gb': 'unknown',
             'pools': None,
             'snapshot_support': True,
+            'create_share_from_snapshot_support': True,
+            'revert_to_snapshot_support': False,
+            'mount_snapshot_support': False,
+            'share_group_stats': {
+                'consistent_snapshot_support': None,
+            },
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'ipv4_support': True,
+            'ipv6_support': False,
         }
         self.assertEqual(test_data, self._driver._stats)
 
