@@ -14,9 +14,9 @@
 #    under the License.
 
 import time
+from unittest import mock
 
 import ddt
-import mock
 from oslo_concurrency import processutils as putils
 from oslo_config import cfg
 import paramiko
@@ -1491,7 +1491,8 @@ class HNASSSHTestCase(test.TestCase):
                                                       look_for_keys=False,
                                                       timeout=None,
                                                       password=self.password,
-                                                      port=self.port)
+                                                      port=self.port,
+                                                      banner_timeout=None)
         self.assertIn('Request submitted successfully.', output)
 
     def test__execute_ssh_exception(self):
