@@ -17,12 +17,13 @@
 Share driver test for Inspur AS13000
 """
 
-import ddt
 import json
-import mock
+import time
+from unittest import mock
+
+import ddt
 from oslo_config import cfg
 import requests
-import time
 
 from manila import context
 from manila import exception
@@ -448,7 +449,7 @@ class AS13000ShareDriverTestCase(test.TestCase):
 
         if share_proto == 'nfs':
             mock_cns.assert_called_once_with(share_path='/fake/path')
-        elif share['share_proto'] is 'cifs':
+        elif share['share_proto'] == 'cifs':
             mock_ccs.assert_called_once_with(share_path='/fake/path',
                                              share_name='share_fakeinstanceid')
 
@@ -480,7 +481,7 @@ class AS13000ShareDriverTestCase(test.TestCase):
 
         if share_proto == 'nfs':
             mock_cns.assert_called_once_with(share_path='/fake/path')
-        elif share['share_proto'] is 'cifs':
+        elif share['share_proto'] == 'cifs':
             mock_ccs.assert_called_once_with(share_path='/fake/path',
                                              share_name='share_fakeinstanceid')
 
@@ -582,7 +583,7 @@ class AS13000ShareDriverTestCase(test.TestCase):
 
         if share_proto == 'nfs':
             mock_gns.assert_called_once_with(r'/P/share_fakeinstanceid')
-        elif share['share_proto'] is 'cifs':
+        elif share['share_proto'] == 'cifs':
             mock_gcs.assert_called_once_with(r'share_fakeinstanceid')
 
     def test_create_snapshot(self):
@@ -653,7 +654,7 @@ class AS13000ShareDriverTestCase(test.TestCase):
         result = self.driver.transfer_rule_to_client(proto, rule)
 
         client = {'name': '1.1.1.1',
-                  'authority':  'rwx' if proto == 'cifs' else 'rw'}
+                  'authority': 'rwx' if proto == 'cifs' else 'rw'}
 
         if proto == 'nfs':
             client.update({'type': 0})
@@ -1085,7 +1086,7 @@ class AS13000ShareDriverTestCase(test.TestCase):
         result = self.driver._get_location_path('fake_name',
                                                 '/fake/path',
                                                 proto)
-        if proto is 'nfs':
+        if proto == 'nfs':
             expect = [{'path': 'ip1:/fake/path'},
                       {'path': 'ip2:/fake/path'}]
         else:
@@ -1147,8 +1148,8 @@ class AS13000ShareDriverTestCase(test.TestCase):
 
     @ddt.data('5000000000', '5000000k', '5000mb', '50G', '5TB')
     def test__unit_convert(self, capacity):
-        trans = {'5000000000': '%.0f' % (float(5000000000) / 1024**3),
-                 '5000000k': '%.0f' % (float(5000000) / 1024**2),
+        trans = {'5000000000': '%.0f' % (float(5000000000) / 1024 ** 3),
+                 '5000000k': '%.0f' % (float(5000000) / 1024 ** 2),
                  '5000mb': '%.0f' % (float(5000) / 1024),
                  '50G': '%.0f' % float(50),
                  '5TB': '%.0f' % (float(5) * 1024)}
