@@ -12,9 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 from lxml import etree
-import mock
-import requests
+from six.moves import urllib
 
 from manila.share.drivers.netapp.dataontap.client import api
 
@@ -2195,6 +2196,46 @@ VOLUME_GET_ITER_CLONE_CHILDREN_RESPONSE = etree.XML("""
     'clone2': CLONE_CHILD_2,
 })
 
+VOLUME_GET_ITER_PARENT_SNAP_EMPTY_RESPONSE = etree.XML("""
+  <results status="passed">
+    <attributes-list>
+      <volume-attributes>
+        <volume-id-attributes>
+          <name>%(name)s</name>
+          <owning-vserver-name>%(vserver)s</owning-vserver-name>
+        </volume-id-attributes>
+      </volume-attributes>
+    </attributes-list>
+    <num-records>1</num-records>
+  </results>
+""" % {
+    'vserver': VSERVER_NAME,
+    'name': SHARE_NAME,
+})
+
+VOLUME_GET_ITER_PARENT_SNAP_RESPONSE = etree.XML("""
+  <results status="passed">
+    <attributes-list>
+      <volume-attributes>
+        <volume-clone-attributes>
+          <volume-clone-parent-attributes>
+            <snapshot-name>%(snapshot_name)s</snapshot-name>
+          </volume-clone-parent-attributes>
+        </volume-clone-attributes>
+        <volume-id-attributes>
+          <name>%(name)s</name>
+          <owning-vserver-name>%(vserver)s</owning-vserver-name>
+        </volume-id-attributes>
+      </volume-attributes>
+    </attributes-list>
+    <num-records>1</num-records>
+  </results>
+""" % {
+    'snapshot_name': SNAPSHOT_NAME,
+    'vserver': VSERVER_NAME,
+    'name': SHARE_NAME,
+})
+
 SIS_GET_ITER_RESPONSE = etree.XML("""
   <results status="passed">
     <attributes-list>
@@ -2597,7 +2638,7 @@ FAKE_RESULT_API_ERRNO_VALID.add_attr('errno', '14956')
 FAKE_RESULT_SUCCESS = api.NaElement('result')
 FAKE_RESULT_SUCCESS.add_attr('status', 'passed')
 
-FAKE_HTTP_SESSION = requests.Session()
+FAKE_HTTP_OPENER = urllib.request.build_opener()
 
 FAKE_MANAGE_VOLUME = {
     'aggregate': SHARE_AGGREGATE_NAME,
