@@ -18,9 +18,11 @@
 """
 Tests for NetApp API layer
 """
+
+from unittest import mock
+
 import ddt
-import mock
-import requests
+from six.moves import urllib
 
 from manila import exception
 from manila.share.drivers.netapp.dataontap.client import api
@@ -137,13 +139,13 @@ class NetAppApiElementTransTests(test.TestCase):
         root['l'] = ['l1', 'l2']
         root['t'] = ('t1', 't2')
 
-        l = root.get_child_by_name('l')
-        self.assertIsInstance(l, api.NaElement)
+        li = root.get_child_by_name('l')
+        self.assertIsInstance(li, api.NaElement)
         t = root.get_child_by_name('t')
         self.assertIsInstance(t, api.NaElement)
 
-        self.assertEqual(2, len(l.get_children()))
-        for le in l.get_children():
+        self.assertEqual(2, len(li.get_children()))
+        for le in li.get_children():
             self.assertIn(le.get_name(), ['l1', 'l2'])
 
         self.assertEqual(2, len(t.get_children()))
@@ -188,12 +190,14 @@ class NetAppApiServerTests(test.TestCase):
         """Tests handling of HTTPError"""
         na_element = fake.FAKE_NA_ELEMENT
         self.mock_object(self.root, '_create_request', mock.Mock(
-            return_value=fake.FAKE_NA_ELEMENT))
+            return_value=('abc', fake.FAKE_NA_ELEMENT)))
         self.mock_object(api, 'LOG')
-        self.root._session = fake.FAKE_HTTP_SESSION
-        self.mock_object(self.root, '_build_session')
-        self.mock_object(self.root._session, 'post', mock.Mock(
-            side_effect=requests.HTTPError()))
+        self.root._opener = fake.FAKE_HTTP_OPENER
+        self.mock_object(self.root, '_build_opener')
+        self.mock_object(self.root._opener, 'open', mock.Mock(
+            side_effect=urllib.error.HTTPError(url='', hdrs='',
+                                               fp=None, code='401',
+                                               msg='httperror')))
 
         self.assertRaises(api.NaApiError, self.root.invoke_elem,
                           na_element)
@@ -202,12 +206,12 @@ class NetAppApiServerTests(test.TestCase):
         """Tests handling of URLError"""
         na_element = fake.FAKE_NA_ELEMENT
         self.mock_object(self.root, '_create_request', mock.Mock(
-            return_value=fake.FAKE_NA_ELEMENT))
+            return_value=('abc', fake.FAKE_NA_ELEMENT)))
         self.mock_object(api, 'LOG')
-        self.root._session = fake.FAKE_HTTP_SESSION
-        self.mock_object(self.root, '_build_session')
-        self.mock_object(self.root._session, 'post', mock.Mock(
-            side_effect=requests.URLRequired()))
+        self.root._opener = fake.FAKE_HTTP_OPENER
+        self.mock_object(self.root, '_build_opener')
+        self.mock_object(self.root._opener, 'open', mock.Mock(
+            side_effect=urllib.error.URLError(reason='urlerror')))
 
         self.assertRaises(exception.StorageCommunicationException,
                           self.root.invoke_elem,
@@ -217,11 +221,11 @@ class NetAppApiServerTests(test.TestCase):
         """Tests handling of Unknown Exception"""
         na_element = fake.FAKE_NA_ELEMENT
         self.mock_object(self.root, '_create_request', mock.Mock(
-            return_value=fake.FAKE_NA_ELEMENT))
+            return_value=('abc', fake.FAKE_NA_ELEMENT)))
         self.mock_object(api, 'LOG')
-        self.root._session = fake.FAKE_HTTP_SESSION
-        self.mock_object(self.root, '_build_session')
-        self.mock_object(self.root._session, 'post', mock.Mock(
+        self.root._opener = fake.FAKE_HTTP_OPENER
+        self.mock_object(self.root, '_build_opener')
+        self.mock_object(self.root._opener, 'open', mock.Mock(
             side_effect=Exception))
 
         exception = self.assertRaises(api.NaApiError, self.root.invoke_elem,
@@ -243,18 +247,15 @@ class NetAppApiServerTests(test.TestCase):
         self.root._trace = trace_enabled
         self.root._api_trace_pattern = trace_pattern
         self.mock_object(self.root, '_create_request', mock.Mock(
-            return_value=fake.FAKE_NA_ELEMENT))
+            return_value=('abc', fake.FAKE_NA_ELEMENT)))
         self.mock_object(api, 'LOG')
-        self.root._session = fake.FAKE_HTTP_SESSION
-        self.mock_object(self.root, '_build_session')
+        self.root._opener = fake.FAKE_HTTP_OPENER
+        self.mock_object(self.root, '_build_opener')
         self.mock_object(self.root, '_get_result', mock.Mock(
             return_value=fake.FAKE_NA_ELEMENT))
-
-        response = mock.Mock()
-        response.text = 'res1'
-        self.mock_object(
-            self.root._session, 'post', mock.Mock(
-                return_value=response))
+        opener_mock = self.mock_object(
+            self.root._opener, 'open', mock.Mock())
+        opener_mock.read.side_effect = ['resp1', 'resp2']
 
         self.root.invoke_elem(na_element)
 
