@@ -14,9 +14,9 @@
 
 import copy
 import time
+from unittest import mock
 
 import ddt
-import mock
 from oslo_config import cfg
 
 from manila import exception
@@ -51,19 +51,19 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
         self.config.append_config_values(na_opts.netapp_transport_opts)
         self.config.append_config_values(na_opts.netapp_support_opts)
         self.config.append_config_values(na_opts.netapp_provisioning_opts)
-        self.config.append_config_values(na_opts.netapp_replication_opts)
+        self.config.append_config_values(na_opts.netapp_data_motion_opts)
         CONF.set_override("share_backend_name", self.backend,
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
         CONF.set_override("netapp_transport_type", "https",
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
         CONF.set_override("netapp_login", "fake_user",
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
         CONF.set_override("netapp_password", "fake_password",
-                          group=self.backend, enforce_type=True)
-        CONF.set_override("netapp_server_hostname", "fake_hostname",
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
+        CONF.set_override("netapp_server_hostname", "fake.hostname",
+                          group=self.backend)
         CONF.set_override("netapp_server_port", 8866,
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
 
     def test_get_client_for_backend(self):
         self.mock_object(data_motion, "get_backend_configuration",
@@ -72,7 +72,7 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
         data_motion.get_client_for_backend(self.backend)
 
         self.mock_cmode_client.assert_called_once_with(
-            hostname='fake_hostname', password='fake_password',
+            hostname='fake.hostname', password='fake_password',
             username='fake_user', transport_type='https', port=8866,
             trace=mock.ANY, vserver=None)
 
@@ -81,19 +81,19 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
                          mock.Mock(return_value=self.config))
 
         CONF.set_override("netapp_vserver", 'fake_vserver',
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
 
         data_motion.get_client_for_backend(self.backend)
 
         self.mock_cmode_client.assert_called_once_with(
-            hostname='fake_hostname', password='fake_password',
+            hostname='fake.hostname', password='fake_password',
             username='fake_user', transport_type='https', port=8866,
             trace=mock.ANY, vserver='fake_vserver')
 
     def test_get_config_for_backend(self):
         self.mock_object(data_motion, "CONF")
         CONF.set_override("netapp_vserver", 'fake_vserver',
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
         data_motion.CONF.list_all_sections.return_value = [self.backend]
 
         config = data_motion.get_backend_configuration(self.backend)
@@ -103,9 +103,9 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
     def test_get_config_for_backend_different_backend_name(self):
         self.mock_object(data_motion, "CONF")
         CONF.set_override("netapp_vserver", 'fake_vserver',
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
         CONF.set_override("share_backend_name", "fake_backend_name",
-                          group=self.backend, enforce_type=True)
+                          group=self.backend)
         data_motion.CONF.list_all_sections.return_value = [self.backend]
 
         config = data_motion.get_backend_configuration(self.backend)
@@ -123,6 +123,7 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
                           self.backend)
 
 
+@ddt.ddt
 class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
 
     def setUp(self):
@@ -138,7 +139,7 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
         config.append_config_values(na_opts.netapp_transport_opts)
         config.append_config_values(na_opts.netapp_support_opts)
         config.append_config_values(na_opts.netapp_provisioning_opts)
-        config.append_config_values(na_opts.netapp_replication_opts)
+        config.append_config_values(na_opts.netapp_data_motion_opts)
 
         self.mock_object(data_motion, "get_backend_configuration",
                          mock.Mock(return_value=config))
@@ -350,6 +351,22 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
         self.mock_dest_client.mount_volume.assert_called_once_with(
             self.fake_dest_vol_name)
 
+    def test_break_snapmirror_no_mount(self):
+        self.mock_object(self.dm_session, 'quiesce_then_abort')
+
+        self.dm_session.break_snapmirror(self.fake_src_share,
+                                         self.fake_dest_share,
+                                         mount=False)
+
+        self.mock_dest_client.break_snapmirror.assert_called_once_with(
+            self.source_vserver, self.fake_src_vol_name,
+            self.dest_vserver, self.fake_dest_vol_name)
+
+        self.dm_session.quiesce_then_abort.assert_called_once_with(
+            self.fake_src_share, self.fake_dest_share)
+
+        self.assertFalse(self.mock_dest_client.mount_volume.called)
+
     def test_break_snapmirror_wait_for_quiesced(self):
         self.mock_object(self.dm_session, 'quiesce_then_abort')
 
@@ -459,6 +476,56 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
             self.fake_dest_vol_name
         )
 
+    def test_change_snapmirror_source_dhss_true(self):
+        fake_new_src_share = copy.deepcopy(self.fake_src_share)
+        fake_new_src_share['id'] = 'd02d497a-236c-4852-812a-0d39373e312a'
+        fake_new_src_share_name = 'share_d02d497a_236c_4852_812a_0d39373e312a'
+        fake_new_src_share_server = fake_new_src_share['share_server']
+        fake_new_src_ss_name = (
+            fake_new_src_share_server['backend_details']['vserver_name'])
+        self.mock_object(self.dm_session, 'delete_snapmirror')
+        self.mock_object(data_motion, 'get_client_for_backend',
+                         mock.Mock(side_effect=[self.mock_dest_client,
+                                                self.mock_src_client]))
+        mock_backend_config = na_fakes.create_configuration()
+        mock_backend_config.driver_handles_share_servers = True
+        self.mock_object(data_motion, 'get_backend_configuration',
+                         mock.Mock(return_value=mock_backend_config))
+        self.mock_object(self.mock_dest_client, 'get_vserver_peers',
+                         mock.Mock(return_value=[]))
+        peer_cluster_name = 'new_src_cluster_name'
+        self.mock_object(self.mock_src_client, 'get_cluster_name',
+                         mock.Mock(return_value=peer_cluster_name))
+
+        self.dm_session.change_snapmirror_source(
+            self.fake_dest_share, self.fake_src_share, fake_new_src_share,
+            [self.fake_dest_share, self.fake_src_share, fake_new_src_share])
+
+        self.assertEqual(4, self.dm_session.delete_snapmirror.call_count)
+
+        self.mock_dest_client.get_vserver_peers.assert_called_once_with(
+            self.dest_vserver, fake_new_src_ss_name
+        )
+        self.assertTrue(self.mock_src_client.get_cluster_name.called)
+        self.mock_dest_client.create_vserver_peer.assert_called_once_with(
+            self.dest_vserver, fake_new_src_ss_name,
+            peer_cluster_name=peer_cluster_name
+        )
+        self.mock_src_client.accept_vserver_peer.assert_called_once_with(
+            fake_new_src_ss_name, self.dest_vserver
+        )
+        self.dm_session.delete_snapmirror.assert_called_with(
+            mock.ANY, mock.ANY, release=False
+        )
+        self.mock_dest_client.create_snapmirror.assert_called_once_with(
+            mock.ANY, fake_new_src_share_name, mock.ANY,
+            self.fake_dest_vol_name, schedule='hourly'
+        )
+        self.mock_dest_client.resync_snapmirror.assert_called_once_with(
+            mock.ANY, fake_new_src_share_name, mock.ANY,
+            self.fake_dest_vol_name
+        )
+
     def test_get_snapmirrors(self):
         self.mock_object(self.mock_dest_client, 'get_snapmirrors')
 
@@ -495,3 +562,42 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
         self.mock_dest_client.resume_snapmirror.assert_called_once_with(
             self.source_vserver, self.fake_src_vol_name,
             self.dest_vserver, self.fake_dest_vol_name)
+
+    @ddt.data((None, exception.StorageCommunicationException),
+              (exception.StorageCommunicationException, None))
+    @ddt.unpack
+    def test_remove_qos_on_old_active_replica_unreachable_backend(self,
+                                                                  side_eff_1,
+                                                                  side_eff_2):
+        mock_source_client = mock.Mock()
+        self.mock_object(data_motion, 'get_client_for_backend',
+                         mock.Mock(return_value=mock_source_client))
+        self.mock_object(
+            mock_source_client, 'set_qos_policy_group_for_volume',
+            mock.Mock(side_effect=side_eff_1))
+        self.mock_object(
+            mock_source_client, 'mark_qos_policy_group_for_deletion',
+            mock.Mock(side_effect=side_eff_2))
+        self.mock_object(data_motion.LOG, 'exception')
+
+        retval = self.dm_session.remove_qos_on_old_active_replica(
+            self.fake_src_share)
+
+        self.assertIsNone(retval)
+        (mock_source_client.set_qos_policy_group_for_volume
+         .assert_called_once_with(self.fake_src_vol_name, 'none'))
+        data_motion.LOG.exception.assert_called_once()
+
+    def test_remove_qos_on_old_active_replica(self):
+        mock_source_client = mock.Mock()
+        self.mock_object(data_motion, 'get_client_for_backend',
+                         mock.Mock(return_value=mock_source_client))
+        self.mock_object(data_motion.LOG, 'exception')
+
+        retval = self.dm_session.remove_qos_on_old_active_replica(
+            self.fake_src_share)
+
+        self.assertIsNone(retval)
+        (mock_source_client.set_qos_policy_group_for_volume
+         .assert_called_once_with(self.fake_src_vol_name, 'none'))
+        data_motion.LOG.exception.assert_not_called()
