@@ -18,12 +18,15 @@ import copy
 from manila.common import constants
 import manila.tests.share.drivers.netapp.fakes as na_fakes
 
-NO_SNAPRESTORE_LICENSE = '"SnapRestore" is not licensed in the cluster.'
+CLUSTER_NAME = 'fake_cluster'
+CLUSTER_NAME_2 = 'fake_cluster_2'
 BACKEND_NAME = 'fake_backend_name'
+BACKEND_NAME_2 = 'fake_backend_name_2'
 DRIVER_NAME = 'fake_driver_name'
 APP_VERSION = 'fake_app_vsersion'
 HOST_NAME = 'fake_host'
 POOL_NAME = 'fake_pool'
+POOL_NAME_2 = 'fake_pool_2'
 VSERVER1 = 'fake_vserver_1'
 VSERVER2 = 'fake_vserver_2'
 LICENSES = ('base', 'cifs', 'fcp', 'flexclone', 'iscsi', 'nfs', 'snapmirror',
@@ -73,6 +76,10 @@ MTU = 1234
 DEFAULT_MTU = 1500
 MANILA_HOST_NAME = '%(host)s@%(backend)s#%(pool)s' % {
     'host': HOST_NAME, 'backend': BACKEND_NAME, 'pool': POOL_NAME}
+MANILA_HOST_NAME_2 = '%(host)s@%(backend)s#%(pool)s' % {
+    'host': HOST_NAME, 'backend': BACKEND_NAME, 'pool': POOL_NAME_2}
+MANILA_HOST_NAME_3 = '%(host)s@%(backend)s#%(pool)s' % {
+    'host': HOST_NAME, 'backend': BACKEND_NAME_2, 'pool': POOL_NAME_2}
 QOS_EXTRA_SPEC = 'netapp:maxiops'
 QOS_SIZE_DEPENDENT_EXTRA_SPEC = 'netapp:maxbpspergib'
 QOS_NORMALIZED_SPEC = 'maxiops'
@@ -365,6 +372,16 @@ SHARE_SERVER = {
                             ADMIN_NETWORK_ALLOCATIONS),
 }
 
+SHARE_SERVER_2 = {
+    'id': 'fake_id_2',
+    'share_network_id': 'c5b3a865-56d0-4d88-abe5-879965e099c9',
+    'backend_details': {
+        'vserver_name': VSERVER2
+    },
+    'network_allocations': (USER_NETWORK_ALLOCATIONS +
+                            ADMIN_NETWORK_ALLOCATIONS),
+}
+
 VSERVER_PEER = [{
     'vserver': VSERVER1,
     'peer-vserver': VSERVER2,
@@ -662,7 +679,6 @@ POOLS = [
         'total_capacity_gb': 3.3,
         'free_capacity_gb': 1.1,
         'allocated_capacity_gb': 2.2,
-        'qos': 'False',
         'reserved_percentage': 5,
         'dedupe': [True, False],
         'compression': [True, False],
@@ -685,7 +701,6 @@ POOLS = [
         'total_capacity_gb': 6.0,
         'free_capacity_gb': 2.0,
         'allocated_capacity_gb': 4.0,
-        'qos': 'False',
         'reserved_percentage': 5,
         'dedupe': [True, False],
         'compression': [True, False],
@@ -711,7 +726,6 @@ POOLS_VSERVER_CREDS = [
         'total_capacity_gb': 'unknown',
         'free_capacity_gb': 1.1,
         'allocated_capacity_gb': 0.0,
-        'qos': 'False',
         'reserved_percentage': 5,
         'dedupe': [True, False],
         'compression': [True, False],
@@ -731,7 +745,6 @@ POOLS_VSERVER_CREDS = [
         'total_capacity_gb': 'unknown',
         'free_capacity_gb': 2.0,
         'allocated_capacity_gb': 0.0,
-        'qos': 'False',
         'reserved_percentage': 5,
         'dedupe': [True, False],
         'compression': [True, False],
