@@ -16,9 +16,9 @@ Mock unit tests for the NetApp driver protocols CIFS class module.
 """
 
 import copy
+from unittest import mock
 
 import ddt
-import mock
 
 from manila.common import constants
 from manila import exception
