@@ -16,11 +16,12 @@
 """Unit tests for the Share driver module."""
 
 import time
+from unittest import mock
+
 
 import ddt
-import mock
-from mock import PropertyMock
 
+from manila.common import constants
 from manila import exception
 from manila import network
 from manila.share import configuration
@@ -153,6 +154,12 @@ class ShareDriverTestCase(test.TestCase):
             self.assertIn(key, result)
         self.assertEqual('Open Source', result['vendor_name'])
 
+    def test_get_share_status(self):
+        share_driver = self._instantiate_share_driver(None, False)
+        self.assertRaises(NotImplementedError,
+                          share_driver.get_share_status,
+                          None, None)
+
     @ddt.data(
         {'opt': True, 'allowed': True},
         {'opt': True, 'allowed': (True, False)},
@@ -261,7 +268,7 @@ class ShareDriverTestCase(test.TestCase):
 
     def test_snapshot_support_exists(self):
         driver.CONF.set_default('driver_handles_share_servers', True)
-        fake_method = lambda *args, **kwargs: None
+        fake_method = lambda *args, **kwargs: None  # noqa: E731
         child_methods = {
             "create_snapshot": fake_method,
             "delete_snapshot": fake_method,
@@ -292,7 +299,7 @@ class ShareDriverTestCase(test.TestCase):
         driver.CONF.set_default('driver_handles_share_servers', True)
 
         common_drv_methods, child_drv_methods = [
-            {method_name: lambda *args, **kwargs: None
+            {method_name: lambda *args, **kwargs: None  # noqa: E731
              for method_name in method_names}
             for method_names in (common_drv_meth_names,
                                  child_drv_meth_names)]
@@ -316,7 +323,7 @@ class ShareDriverTestCase(test.TestCase):
     )
     def test_snapshot_support_absent(self, methods):
         driver.CONF.set_default('driver_handles_share_servers', True)
-        fake_method = lambda *args, **kwargs: None
+        fake_method = lambda *args, **kwargs: None  # noqa: E731
         child_methods = {}
         for method in methods:
             child_methods[method] = fake_method
@@ -349,7 +356,7 @@ class ShareDriverTestCase(test.TestCase):
     def test_snapshot_support_exists_and_set_explicitly(
             self, snapshots_are_supported):
         driver.CONF.set_default('driver_handles_share_servers', True)
-        fake_method = lambda *args, **kwargs: None
+        fake_method = lambda *args, **kwargs: None  # noqa: E731
         child_methods = {
             "create_snapshot": fake_method,
             "delete_snapshot": fake_method,
@@ -368,7 +375,7 @@ class ShareDriverTestCase(test.TestCase):
 
     def test_create_share_from_snapshot_support_exists(self):
         driver.CONF.set_default('driver_handles_share_servers', True)
-        fake_method = lambda *args, **kwargs: None
+        fake_method = lambda *args, **kwargs: None  # noqa: E731
         child_methods = {
             "create_share_from_snapshot": fake_method,
             "create_snapshot": fake_method,
@@ -391,7 +398,7 @@ class ShareDriverTestCase(test.TestCase):
     )
     def test_create_share_from_snapshot_support_absent(self, methods):
         driver.CONF.set_default('driver_handles_share_servers', True)
-        fake_method = lambda *args, **kwargs: None
+        fake_method = lambda *args, **kwargs: None  # noqa: E731
         child_methods = {}
         for method in methods:
             child_methods[method] = fake_method
@@ -427,7 +434,7 @@ class ShareDriverTestCase(test.TestCase):
     def test_create_share_from_snapshot_exists_and_set_explicitly(
             self, create_share_from_snapshot_supported):
         driver.CONF.set_default('driver_handles_share_servers', True)
-        fake_method = lambda *args, **kwargs: None
+        fake_method = lambda *args, **kwargs: None  # noqa: E731
         child_methods = {"create_share_from_snapshot": fake_method}
         child_class_instance = type(
             "NotRedefined", (driver.ShareDriver, ), child_methods)(True)
@@ -789,6 +796,97 @@ class ShareDriverTestCase(test.TestCase):
         self.assertIsNone(share_group_update)
         self.assertEqual(expected_share_updates, share_update)
 
+    def test_create_share_group_from_share_group_snapshot_with_dict_raise(
+            self):
+        share_driver = self._instantiate_share_driver(None, False)
+        fake_shares = [
+            {'id': 'fake_share_%d' % i,
+             'source_share_group_snapshot_member_id': 'fake_member_%d' % i}
+            for i in (1, 2)]
+        fake_share_group_dict = {
+            'source_share_group_snapshot_id': 'some_fake_uuid_abc',
+            'shares': fake_shares,
+            'id': 'some_fake_uuid_def',
+        }
+        fake_share_group_snapshot_dict = {
+            'share_group_snapshot_members': [
+                {'id': 'fake_member_1'}, {'id': 'fake_member_2'}],
+            'id': 'fake_share_group_snapshot_id',
+        }
+
+        self.mock_object(
+            share_driver, 'create_share_from_snapshot',
+            mock.Mock(side_effect=[{
+                'export_locations': 'fake_export1',
+                'status': constants.STATUS_CREATING},
+                {'export_locations': 'fake_export2',
+                 'status': constants.STATUS_CREATING}]))
+
+        self.assertRaises(
+            exception.InvalidShareInstance,
+            share_driver.create_share_group_from_share_group_snapshot,
+            'fake_context',
+            fake_share_group_dict,
+            fake_share_group_snapshot_dict)
+
+    def test_create_share_group_from_share_group_snapshot_with_dict(
+            self):
+        share_driver = self._instantiate_share_driver(None, False)
+        fake_shares = [
+            {'id': 'fake_share_%d' % i,
+             'source_share_group_snapshot_member_id': 'fake_member_%d' % i}
+            for i in (1, 2)]
+        fake_share_group_dict = {
+            'source_share_group_snapshot_id': 'some_fake_uuid_abc',
+            'shares': fake_shares,
+            'id': 'some_fake_uuid_def',
+        }
+        fake_share_group_snapshot_dict = {
+            'share_group_snapshot_members': [
+                {'id': 'fake_member_1'}, {'id': 'fake_member_2'}],
+            'id': 'fake_share_group_snapshot_id',
+        }
+
+        mock_create = self.mock_object(
+            share_driver, 'create_share_from_snapshot',
+            mock.Mock(side_effect=[{
+                'export_locations': 'fake_export1',
+                'status': constants.STATUS_CREATING_FROM_SNAPSHOT},
+                {'export_locations': 'fake_export2',
+                 'status': constants.STATUS_AVAILABLE}]))
+        expected_share_updates = [
+            {
+                'id': 'fake_share_1',
+                'status': constants.STATUS_CREATING_FROM_SNAPSHOT,
+                'export_locations': 'fake_export1',
+            },
+            {
+                'id': 'fake_share_2',
+                'status': constants.STATUS_AVAILABLE,
+                'export_locations': 'fake_export2',
+            },
+        ]
+
+        share_group_update, share_update = (
+            share_driver.create_share_group_from_share_group_snapshot(
+                'fake_context', fake_share_group_dict,
+                fake_share_group_snapshot_dict))
+
+        mock_create.assert_has_calls([
+            mock.call(
+                'fake_context',
+                {'id': 'fake_share_1',
+                 'source_share_group_snapshot_member_id': 'fake_member_1'},
+                {'id': 'fake_member_1'}),
+            mock.call(
+                'fake_context',
+                {'id': 'fake_share_2',
+                 'source_share_group_snapshot_member_id': 'fake_member_2'},
+                {'id': 'fake_member_2'})
+        ])
+        self.assertIsNone(share_group_update)
+        self.assertEqual(expected_share_updates, share_update)
+
     def test_create_share_group_from_sg_snapshot_with_no_members(self):
         share_driver = self._instantiate_share_driver(None, False)
         fake_share_group_dict = {}
@@ -809,8 +907,6 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'should_not_be_used_1',
-            'share_name': 'share_fake_share_instance_id_1',
-            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -823,8 +919,6 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'should_not_be_used_2',
-            'share_name': 'share_fake_share_instance_id_2',
-            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -863,8 +957,6 @@ class ShareDriverTestCase(test.TestCase):
                  'share_instance_id': member['share']['id'],
                  'id': member['id'],
                  'share': member['share'],
-                 'share_name': member['share_name'],
-                 'name': member['name'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
                  'share_proto': member['share']['share_proto'],
@@ -887,8 +979,6 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'should_not_be_used_1',
-            'share_name': 'share_fake_share_instance_id_1',
-            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -901,8 +991,6 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'should_not_be_used_2',
-            'share_name': 'share_fake_share_instance_id_2',
-            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -942,8 +1030,6 @@ class ShareDriverTestCase(test.TestCase):
             'share_instance_id': fake_snap_member_1['share']['id'],
             'id': fake_snap_member_1['id'],
             'share': fake_snap_member_1['share'],
-            'share_name': fake_snap_member_1['share_name'],
-            'name': fake_snap_member_1['name'],
             'size': fake_snap_member_1['share']['size'],
             'share_size': fake_snap_member_1['share']['size'],
             'share_proto': fake_snap_member_1['share']['share_proto'],
@@ -957,8 +1043,6 @@ class ShareDriverTestCase(test.TestCase):
                  'share_instance_id': member['share']['id'],
                  'id': member['id'],
                  'share': member['share'],
-                 'share_name': member['share_name'],
-                 'name': member['name'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
                  'share_proto': member['share']['share_proto'],
@@ -1034,8 +1118,6 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'fake_provider_location_2',
-            'share_name': 'share_fake_share_instance_id_1',
-            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -1048,8 +1130,6 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'fake_provider_location_2',
-            'share_name': 'share_fake_provider_location_2',
-            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -1088,8 +1168,6 @@ class ShareDriverTestCase(test.TestCase):
                  'share': member['share'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
-                 'share_name': member['share_name'],
-                 'name': member['name'],
                  'share_proto': member['share']['share_proto'],
                  'provider_location': member['provider_location']},
                 share_server=None)
@@ -1132,7 +1210,7 @@ class ShareDriverTestCase(test.TestCase):
         share_driver = self._instantiate_share_driver(None, True)
         self.mock_object(share_driver, 'get_configured_ip_versions',
                          mock.Mock(return_value=conf))
-        versions = PropertyMock(return_value=user_networks)
+        versions = mock.PropertyMock(return_value=user_networks)
         type(share_driver.network_api).enabled_ip_versions = versions
         data = {'share_backend_name': 'fake_backend'}
 
