@@ -15,10 +15,10 @@
 import itertools
 import sys
 import textwrap
+from unittest import mock
 
 import ddt
-import mock
-import pep8
+import pycodestyle
 
 from manila.hacking import checks
 from manila import test
@@ -112,14 +112,14 @@ class HackingTestCase(test.TestCase):
 
     # We are patching pep8 so that only the check under test is actually
     # installed.
-    @mock.patch('pep8._checks',
+    @mock.patch('pycodestyle._checks',
                 {'physical_line': {}, 'logical_line': {}, 'tree': {}})
     def _run_check(self, code, checker, filename=None):
-        pep8.register_check(checker)
+        pycodestyle.register_check(checker)
 
         lines = textwrap.dedent(code).strip().splitlines(True)
 
-        checker = pep8.Checker(filename=filename, lines=lines)
+        checker = pycodestyle.Checker(filename=filename, lines=lines)
         checker.check_all()
         checker.report._deferred_print.sort()
         return checker.report._deferred_print
@@ -155,7 +155,7 @@ class HackingTestCase(test.TestCase):
                       "climbing.", ('volume1', 500))
                """
         self._assert_has_errors(code.format(log_method), checker,
-                                expected_errors=[(4, 21, 'M310')])
+                                expected_errors=[(4, mock.ANY, 'M310')])
 
     def test_str_on_exception(self):
 
@@ -314,13 +314,6 @@ class HackingTestCase(test.TestCase):
         self.assertEqual(1, len(list(checks.validate_assertTrue(
             "assertEqual(True, %s)" % test_value))))
 
-    def test_validate_assertIsNone(self):
-        test_value = None
-        self.assertEqual(0, len(list(checks.validate_assertIsNone(
-            "assertIsNone(None)"))))
-        self.assertEqual(1, len(list(checks.validate_assertIsNone(
-            "assertEqual(None, %s)" % test_value))))
-
     def test_check_uuid4(self):
         code = """
             fake_uuid = uuid.uuid4()
@@ -334,6 +327,16 @@ class HackingTestCase(test.TestCase):
                """
         self._assert_has_no_errors(code, checks.check_uuid4)
 
+    @ddt.unpack
+    @ddt.data(
+        (1, 'import mock'),
+        (0, 'from unittest import mock'),
+        (1, 'from mock import patch'),
+        (0, 'from unittest.mock import patch'))
+    def test_no_third_party_mock(self, err_count, line):
+        self.assertEqual(err_count,
+                         len(list(checks.no_third_party_mock(line))))
+
     def test_no_log_warn_check(self):
         self.assertEqual(0, len(list(checks.no_log_warn_check(
             "LOG.warning('This should not trigger LOG.warn "
