@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 
 from manila import exception
@@ -711,6 +712,7 @@ class QuotaEngineTestCase(test.TestCase):
 
     def test_current_common_resources(self):
         self.assertEqual(
-            ['gigabytes', 'share_group_snapshots', 'share_groups',
-             'share_networks', 'shares', 'snapshot_gigabytes', 'snapshots'],
+            ['gigabytes', 'replica_gigabytes', 'share_group_snapshots',
+             'share_groups', 'share_networks', 'share_replicas', 'shares',
+             'snapshot_gigabytes', 'snapshots'],
             quota.QUOTAS.resources)
